<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Ядро сайта
 */

class Kernel
{
	public static function run()
	{
		try
		{
			self::callConfigData();
			self::callRouter();
			self::callLanguage();
			self::connectDB();
			self::setPrivileges();
			self::callServices();
			self::callBlocks();
			self::callModules();
		}
		catch (Exception_Message $e)
		{
			header('HTTP/1.0 403 Forbidden');
			Log::add($e, Log::TITLE_MESSAGE, Log::FILE_MESSAGE);

			Site::setSkinVar("module_title", FALSE);
			Site::setSkinVar("content",Site::getPage('page', array(
				'title' 	=> Lng::_('Предупреждение'),
				'message' 	=> '<span class="'.($e -> getCode() == 1 ? 'important' : '').'"><b>'.$e -> getMessage().'</b></span>'
			)));
		}
		catch (Exception_Privileges $e)
		{
			header('HTTP/1.0 403 Forbidden');
			Log::add($e, Log::TITLE_PRIVILEGES, Log::FILE_PRIVILEGES);

			Site::setSkinVar("module_title", FALSE);
			Site::setSkinVar("content",Site::getPage('page', array(
				'title' 	=> Lng::_('Доступ ограничен'),
				'message' 	=> Lng::_('Доступ к просматриваемому разделу закрыт. Возможно Вам следует '.Helper_HTML::anchor('index.php?mod=users', 'авторизироваться').' на сайте.')
			)));
		}
		catch (Exception_440 $e) /*TODO заменить на "Exception_440"*/
		{
			header('HTTP/1.0 404 Not Found');
//			header('HTTP/1.1 404 Not Found');
//			header('Status: 404 Not Found');
			Log::add($e, Log::TITLE_440, Log::FILE_440);

			//Если код равен "1" отображаем стандартное сообщение об ошибке, а переданное записываем в лог
			if($e -> getCode() == 1)
			{
				$message = Lng::_('Запрашиваемая Вами страница не найдена. Возможно Вы перешли по старой или некорректной ссылке.');
			}
			else
			{
				$message = $e -> getMessage();
			}
			
			Site::setSkinVar("module_title", FALSE);
			Site::setSkinVar("content",Site::getPage('page', array(
				'title' 	=> Lng::_('440 Страница не найдена'),
				'message' 	=> $message
			)));
			//Подключаем пользовательский поиск от Google или Yandex
			Site::addSkinVar("content", View::get('skins/common/search'));
		}
		catch (Exception_DB $e)
		{
			header('HTTP/1.0 403 Forbidden');
			Log::add($e, Log::TITLE_DB, Log::FILE_DB);
			
			//Получаем системное сообщение об ошибке
			$msg = (string) Registry::get('Config') -> messages -> db;
			
			//Исключения БД логируются в конструкторе Exception_DB
			Site::setSkinVar("module_title", FALSE);
			Site::setSkinVar("content",Site::getPage('page', array(
				'title' => Lng::_('Ошибка базы данных'),
				'message' => $msg ? $msg : $e -> getMessage(),
			)));
		}
		catch (Exception_Ajax $e)
		{
			header('HTTP/1.0 403 Forbidden');
			Log::add($e, Log::TITLE_AJAX, Log::FILE_AJAX);
			
			//Исключения БД логируются в конструкторе Exception_DB
			Site::setSkinVar("module_title", FALSE);
			Site::setSkinVar("content",Site::getPage('page', array(
				'title' => Lng::_('Некорректная работа браузера'),
				'message' => 'Включите поддержку JavaScript в своем браузере и вернитесь на предыдущую страницу.',
			)));
		}
		catch (Exception $e)
		{
			header('HTTP/1.0 500 Internal Server Error');
			Log::add($e, Log::TITLE_500, Log::FILE_500);

			//Получаем системное сообщение об ошибке
			$msg = (string) Registry::get('Config') -> messages -> error;
			
			Site::setSkinVar("module_title", FALSE);
			Site::setSkinVar("content",Site::getPage('page', array(
				'title' 	=> Lng::_('Ошибка 500'),
				'message' 	=> $msg ? $msg : (Registry::get('is_debug') == 1 ? $e -> getMessage() : Lng::_('Ошибка 500. Внутренняя ошибка сервера')),
			)));
		}
		self::displaySite();
	}

	/**
	 * Подключаем системные языки
	 *
	 */
	private static function callLanguage()
	{
		Lng::setLng('common');
		if(User::isCPanel() == TRUE)
		{
			Lng::setLng('back-end');
		}
		else
		{
			Lng::setLng('front-end');
		}
	}
	
	/**
	 * Вызываем запрошенный пользователем модуль
	 *
	 */
	private static function callModules()
	{
		$Config 		=& Registry::get('Config');
		$Modules 		=& Registry::get('Modules');
		$base_file 		= Site::getBaseFile();
		
		if($_SERVER['QUERY_STRING'] == FALSE)
		{
			$_GET['mod'] 	= (string)$Config -> module -> $base_file -> mod; 
			$_GET['go'] 	= (string)$Config -> module -> $base_file -> go;
		}
		$_GET['mod'] 	= $mod 	= Request::getGet("mod","string","index");
		$_GET['go'] 	= $go 	= Request::getGet("go","string","index");

		$sub_control 	= '';
		$sub_control_p 	= '';
		$mod_ar 		= explode('.',$mod);
		if(sizeof($mod_ar) > 1)
		{
			$mod 			= trim($mod_ar[0]);
			$sub_control 	= strtolower(trim($mod_ar[1]));
			
			if($sub_control == FALSE)
			{
				throw new Exception_440('Попытка вызова пустого субконтроллера [параметр '.$sub_control.']', 1);
			}
			
			$sub_control_p 	= ".".$sub_control;
		}
		if($mod == FALSE)
		{
			throw new Exception_440('Попытка вызова пустого контроллера [параметр '.$mod.']', 1);
		} 

		//Проверяем наличие суб контроллера
		if(is_file("./modules/".$mod."/controllers/".$base_file.$sub_control_p.".php") == FALSE)
		{
			throw new Exception_440('Попытка вызова файла не существующего контроллера [/modules/'.$mod.'/controllers/'.$base_file.$sub_control_p.'.php]', 1);
		}
		//Подключаем контроллер
		include_once("./modules/".$mod."/controllers/".$base_file.$sub_control_p.".php");

		//Вызываем модуль
		$Module =  $Modules -> $mod;	
		$class = "Modules_".$mod."_Controllers_".$base_file.$sub_control;
		$Controller = new $class();
		if($Module['access'] == 1)
		{
			if(method_exists($Controller, $go."Action") == FALSE)
			{
				throw new Exception_440('Попытка вызова не существующего экшена контроллера ['.$go.'Action]', 1);
			}

			if(User::isCPanel() == TRUE)
			{
				Site::setSkinVar('module_title',$Module['title']);
			}
			
			$Controller -> setParams($base_file,$mod,$sub_control_p,$go,"modules");
			$Controller -> callView();
			$Controller -> {$go."Action"}();
			$Controller -> showMessage();
			Site::addSkinVar('content',$Controller -> getView());
		}
	}
	
	/**
	 * Вызов блоков
	 *
	 */
	private static function callBlocks()
	{
		if(User::isCPanel() == TRUE){return TRUE;}
		
		$Blocks 	=& XML::getObj('./files/configure/blocks.xml');
		
		foreach($Blocks -> block as $Block)
		{
			$is_show 	= FALSE;
			$Block['name'] = strtolower($Block['name']);
			if(@is_file('./blocks/'.$Block['name'].'/block.php') == FALSE || $Block['access'] == 0)
			{
				continue;
			}

			$is_show = CheckAccess::privileges(User::get('role'), $Block['privileges']);
			if($is_show == TRUE)
			{
				//Определяем в каих случаях отображать блок
				$is_show = CheckAccess::toModule(Site::getCurrentModule(),$Block['modules']);
			}
			if($is_show == TRUE)
			{
				//Подключаем динамический
				$class = "Blocks_".$Block['name']."_Block";
				$DBlock = new $class($Block);
				if(isset($Block['action']))
				{
					$action = (string)$Block['action']."Action";
					if(method_exists($DBlock,$action))
					{
						$DBlock -> setParams(NULL, $Block['name'], NULL, $Block['action'], 'blocks');
						$DBlock -> callView();
						$DBlock -> $action();
					}
				}
				if($bcontent = $DBlock -> getView())
				{
					Site::addSkinVar($Block['place'],self::getBlock($Block['title'],$bcontent,$Block['skin']));
				}
			}
		}
	}
	
	/**
	 * Вызов служб
	 *
	 * @param string $call_method вызываемый метод
	 */
	private static function callServices()
	{
		if(User::isCPanel() == TRUE){return TRUE;}
		
		$Services 	=& XML::getObj('./files/configure/services.xml');
		
		foreach($Services -> service as $Service)
		{
			$is_show 	= FALSE;
			
			$Service['name'] = strtolower($Service['name']);
			if(@is_file('./services/'.$Service['name'].'/service.php') == FALSE || $Service['access'] == 0)
			{
				continue;
			}

			$is_show = CheckAccess::privileges(User::get('role'),$Service['privileges']);
			if($is_show)
			{
				//Определяем в каих случаях вызывать сервис
				$is_show = CheckAccess::toModule(Site::getCurrentModule(),$Service['modules']);
			}
			if($is_show)
			{
				$class = "Services_{$Service['name']}_Service";
				new $class($Service);
			}
		}
	}
	
	/**
	 * Отображает сайт
	 *
	 */
	private static function displaySite()
	{
		$Config =& Registry::get('Config');
		
		if(User::isComeAsAdmin())
		{
			//Формируем меню
			Element_Menu::get(".skin-menubar");
			$skin = Site::getBaseFile();
		}
		else
		{
			$skin 	= $Config -> site -> skin;
			
			if(isset($skin['less']) == TRUE)
			{
				try
				{
					require_once './library/php/vendor/lessc/lessc.inc.php';
					$Less = new lessc;
//					$Less -> setFormatter("compressed");
					$Less -> compileFile('./_data/less/'.$skin['less'].'/'.$skin['file'].'.less','./images/skin/'.$skin.'/style.css');
				}
				catch (exception $e)
				{
					echo $e->getMessage();
					exit;
				}
			}
		}
		
		$Skin = new View("./skins/".$skin."/index.phtml");
		$Skin -> version 				= $Config -> site -> version;
		$Skin -> lng 					= $Config -> site -> language;
		
		if(Site::getSkinVar("keywords") == FALSE)
		{
			$Skin -> keywords = $Config -> site -> keywords;
		}
		if(Site::getSkinVar("description") == FALSE)
		{
			$Skin -> description = $Config -> site -> description;
		}
		$skin_vars = Site::getSkinVars();
		
		foreach($skin_vars as $name => $value)
		{
			@$Skin -> $name .= $value;
		}

		if(Site::getSkinVar("title") == TRUE)
		{
			/*$Skin -> title = $Skin -> title.' | '.$Config -> site -> title;*/
			$Skin -> title = $Skin -> title;
		}
		else
		{
			$Skin -> title = $Config -> site -> title;
		}
		
		if(isset($skin_vars['title_pagination']))
		{
			$Skin -> title .= $skin_vars['title_pagination'];
		}
		
		echo $Skin -> getView();
		if('1' == (string) $Config -> developer -> debug)
		{
			echo Site::showDebug();
		}
		exit;
	}
	
	/**
	 * Устанавливает привилегии
	 *
	 */
	private static function setPrivileges()
	{
		if(User::isAuth() == FALSE)
		{
			User::set('role', User::ROLE_GUEST);
		}
		
		//Если пользователь пытается просмотреть панель администратора, но приэтом не Администратор,
		//перенаправляем его на главную страницу сайта
		if(User::isComeAsAdmin() == TRUE && User::get('role') != User::ROLE_ADMIN)
		{
			URL::redirect('/index.php');
		}
	}
	
	/**
	 * Подключаем БД
	 *
	 */
	private static function connectDB()
	{
		$Config =& Registry::get('Config');
		Registry::set('DB', new DBMysql(
			$Config -> db -> user, 
			$Config -> db -> password, 
			$Config -> db -> host, 
			$Config -> db -> name, 
			$Config -> db -> prefix
		));
	}
	
	/********************************************************************************************************************/
	/************************************************* PRIVATE METHODS **************************************************/
	/********************************************************************************************************************/
	
	/**
	 * Вызывает конфигурационные файлы
	 *
	 */
	private static function callConfigData()
	{
		//Переустанавливаем параметр скина, если пользователь администратор
		$Config = XML::getObj('./files/configure/config.xml');
		
		if(User::isComeAsAdmin() == TRUE)
		{
			$Config  -> site -> skin_user = $Config  -> site -> skin;
			$Config  -> site -> skin = Site::getBaseFile();
		}
		
		//Подулючаем библиотеку проекта
		Registry::set('Config',$Config);
		Registry::set('is_debug',(string)($Config -> developer -> debug));
		Registry::set('Modules',XML::getObj('./files/configure/modules.xml'));
	}
	
	/**
	 * Включаем Роутер
	 *
	 */
	private static function callRouter()
	{
		if(isset($_SERVER['REQUEST_URI']) == FALSE)
		{
			return TRUE;
		}
		//Удаляем возможные иньекции
		$_SERVER['REQUEST_URI'] = Security::xssClean($_SERVER['REQUEST_URI']);
		
		//Проверяем корректность URL
		if(strstr($_SERVER['REQUEST_URI'],'..'))
		{
			throw new Exception_440('Попытка ввода в URL ".."', 1);
		}
		
		URL::callRouter($_SERVER['REQUEST_URI']);
	}
	
	/**
	 * Возвращает содержимое блока
	 *
	 * @param string $title название блока
	 * @param string $content контент блока
	 * @param string $skin оформление блока
	 * @return string
	 */
	private static function getBlock($title = NULL, $content = NULL, $skin = NULL)
	{
		$skin = (string)$skin;
		
		if($skin == TRUE)
		{
			$Config =& Registry::get('Config');

			$Skin = new View("./skins/".$Config -> site -> skin."/".$skin.".phtml");
			$Skin -> title 		= (string)$title;
			$Skin -> content 	= $content;
			$Skin -> skin 		= $Config -> site -> skin;
			return $Skin -> getView();
		}
		return $content;
	}
}