<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс платежной системы interkassa
 */

class Pays_INTERKASSA_Pay
{
	/**
	 * Название платежной системы
	 *
	 * @var string
	 */
	public $name = "Нажмите для оплаты через Интеркассу";
	
	/**
	 * Краткое название платежной системы
	 *
	 * @var string
	 */
	public $name_short = "INTERKASSA";
	
	/**
	 * Код платежной системы
	 *
	 * @var string
	 */
	public $code = "INTERKASSA";
	
	/**
	 * Ссылка на сайт
	 *
	 * @var string
	 */
	public $site = "https://interkassa.com";
	
	/**
	 * Описание
	 *
	 * @var string
	 */
	public $description = "В Интеркассе можете выбрать любой способ оплаты: Карточкой, Webmoney, Приват 24, LiqPay, отправив СМС или по Терминалу. Выбирайте способ, оплачивайте услугу и получайте больше звонков!";
	
	/**
	 * Путь к логотипу платежной системы
	 *
	 * @var string
	 */
	public $path_logo = "/library/pays/interkassa/images/logo.png";

	
	/**
	 * Action формы
	 *
	 * @var string
	 */
	public $form_action = NULL;
	
	/**
	 * Объект дополнительных полей
	 *
	 * @var object
	 */
	public $FormItem = NULL;
	
	/**
	 * Идентификатор магазина (пример: 392894CA-62C4-E3B3-14DC-1CD6058AC6A7s)
	 *
	 * @var string
	 */
	public $ik_co_id;
	
	/**
	 * Сумма платежа
	 *
	 * @var double
	 */
	public $ik_am;
	
	/**
	 * Идентификатор платежа
	 *
	 * @var string
	 */
	public $ik_pm_no;
	
	/**
	 * Описание платежа
	 *
	 * @var string
	 */
	public $ik_desc;
	
	/**
	 * Электронная подпись полученная с сервера
	 *
	 * @var string
	 */
	public $ik_sign;
	
	/**
	 * Состояние платежа
	 * 
	 * @var unknown_type
	 */
	public $ik_inv_st;
	
	/**
	 * Внутренний номер платежа в системе
	 *
	 * @var string
	 */
	public $ik_inv_id;
	
	/**
	 * Дата и время выполнения платежа.
	 *
	 * @var string
	 */
	public $ik_inv_prc;
	
	/**
	 * Секретный ключ
	 *
	 * @var string
	 */
	public $secret_key;
	
	/**
	 * Конструктор класса
	 *
	 */
	public function __construct()
	{
		$this -> FormItem = new stdClass();
	}
	
	/**
	 * Возвращает форму для формирования платежа
	 *
	 * @return string
	 */
	public function getForm()
	{
		return View::get('./library/pays/interkassa/view/form',array(
			'Pay' => $this
		));
	}
	
	/**
	 * Формируем фомрму для оплаты и перехода на сайт
	 *
	 * @return string
	 */
	public function getConfirmForm()
	{
		return View::get('./library/pays/interkassa/view/confirm_form',array(
			'Pay' => $this
		));
	}
	
	/**
	 * Возвращает электронную подпись полученную с сервера, контрольная подпись оповещения о 
	 * выполнении платежа, которая используется для проверки целостности полученной информации и 
	 * однозначной идентификации отправителя. Несмотря на то, что параметр является не обязательным, 
	 * и рекомендуем всегда задавать его для повышения безопасности и сведения к минимуму возможности 
	 * подделки данных платежа злоумышленником. Алгоритм формирования описан в разделе "Контрольная 
	 * подпись данных о платеже".
	 *
	 * @return string
	 */
	public function getIkSignHash()
	{
		$post_ar = Request::post();
		unset($post_ar['ik_sign']);
		ksort($post_ar, SORT_STRING);
		array_push($post_ar, $this -> secret_key);
		
		return base64_encode(
			md5(
				implode(':', $post_ar)
			, true)
		);
	}
	
	/**
	 * Возвращает электронную подпись сформированную пользователем для проверки отправленных данных на сервере
	 * @return string
	 */
	public function getUsSignHash()
	{
		$post_ar = array(
			'ik_co_id' => $this -> ik_co_id,
			'ik_pm_no' => $this -> ik_pm_no,
			'ik_am' => $this -> ik_am,
			'ik_desc' => $this -> ik_desc,
		);
		
		ksort($post_ar, SORT_STRING);
		array_push($post_ar, $this -> secret_key);
		
		return base64_encode(
			md5(
				implode(':', $post_ar)
			, true)
		);
	}
	
	/**
	 * Подготавливает STATUS данные
	 *
	 */
	public function prepareStatusData()
	{
		$post_ar = array(
			'ik_co_id',
			'ik_am',
			'ik_pm_no',
			'ik_desc',
			'ik_inv_prc',
			'ik_inv_st',
			'ik_inv_id',
			'ik_sign',
		);
		
		foreach ($post_ar as $var)
		{
			$this -> $var = $_REQUEST[$var];
		}
	}
	
	/**
	 * Пдготавливает SUCCESS данные полученные с сервера
	 *
	 * @return array
	 */
	public function prepareSuccessData()
	{
		$post_ar = array(
			'ik_co_id',
			'ik_pm_no',
			'ik_inv_prc',
			'ik_inv_st',
			'ik_inv_id',
		);
		
		foreach ($post_ar as $var)
		{
			$this -> $var = $_REQUEST[$var];
		}
	}
	
	/**
	 * Подготавливают FAIL данные полученные с сервера
	 *
	 */
	public function prepareFailData()
	{
		$this -> prepareSuccessData();
	}
	
	/**
	 * Проверяет соответствие полученных данных с контрольной суммой сервера
	 *
	 * @return bool
	 */
	public function checkStatusSignHash()
	{
		return ($this -> getIkSignHash() === $this -> ik_sign);
	}
	
	/**
	 * Воозвращает описание данных в виде массива
	 *
	 * @param string $doc_str 
	 */
	public function getDescriptionObj($doc_str = NULL)
	{
		$data_ar = array(
			'ik_co_id' => array('title' => Lng::_('Идентификатор магазина <small>(зарегистрированного в системе "INTERKASSA")</small>')),
			'ik_am' => array('title' => Lng::_('Сумма платежа <small>которую заплатил покупатель получить от покупателя (с учетом валюты и курса магазина)</small>')),
			'ik_pm_no' => array('title' => Lng::_('Идентификатор покупки.')),
			'ik_desc' => array('title' => Lng::_('Описание товара или услуги.')),
			'ik_inv_prc' => array('title' => Lng::_('Дата и время выполнения платежа <small>в UNIX TIMESTAMP формате</small>.')),
			'ik_inv_st' => array('title' => Lng::_('Состояние (статус) платежа проведенного в системе "INTERKASSA".')),
			'ik_inv_id' => array('title' => Lng::_('Номер платежа в системе "INTERKASSA".')),
			'ik_sign' => array('title' => Lng::_('Контрольная подпись оповещения о выполнении платежа.')),
			'ik_co_prs_id' => array('title' => Lng::_('Идентификатор кошелька кассы.')),
			'_PAY_COOMENT' => array('title' => ''),
		);
		
		//Парсим данные
@		$doc_ar = unserialize($doc_str);
		if($doc_ar && sizeof($doc_ar))
		{
			foreach($doc_ar as $key => $val)
			{
				if(isset($data_ar[$key]))
				{
					$data_ar[$key]['value'] = $val;
				}
			}
		}
		
		return $data_ar;
	}
}