<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс платежной системы LiqPAY  
 */

class Pays_LiqPAY_Pay
{
	/**
	 * Название платежной системы
	 *
	 * @var string
	 */
	public $name = "Платежная система LiqPAY";
	
	/**
	 * Краткое название платежной системы
	 *
	 * @var string
	 */
	public $name_short = "LiqPAY";
	
	/**
	 * Код платежной системы
	 *
	 * @var string
	 */
	public $code = "LiqPAY";
	
	/**
	 * Ссылка на сайт
	 *
	 * @var string
	 */
	public $site = "https://www.liqpay.com";
	
	/**
	 * Описание
	 *
	 * @var string
	 */
	public $description = "LiqPAY — открытая платежная система, которая позволяет перевести деньги с помощью мобильного телефона, интернета и платежных карт во всём мире.";
	
	/**
	 * Путь к логотипу платежной системы
	 *
	 * @var string
	 */
	public $path_logo = "/library/pays/liqpay/images/logo.png";
	
	
	/**
	 * Объект дополнительных полей
	 *
	 * @var object
	 */
	public $FormItem = null;
	
	/**
	 * Объект дополнительных текстовых надписей на форме
	 *
	 * @var object
	 */
	public $FormLabel = null;
	
	/**
	 * Action формы
	 *
	 * @var string
	 */
	public $form_action = null;
	
	
	/**
	 * Объяект с данными для operation_xml
	 *
	 * @var unknown_type
	 */
	public $OperationXml = null;
	
	/**
	 * Сформированный зашифрованный ХМЛ файл
	 *
	 * @var string
	 */
	public $encode_operation_xml = null;
	
	/**
	 * Сформированная зашифрованная подпись
	 *
	 * @var string
	 */
	public $encode_signature = null;
	
	/**
	 * Расшифрованный ХМЛ файл
	 *
	 * @var string
	 */
	public $decode_operation_xml = null;

	/**
	 * Конструктор класса
	 *
	 */
	public function __construct()
	{
		$this -> FormItem 		= new stdClass();
		$this -> OperationXml 	= new stdClass();
		$this -> FormLabel 		= new stdClass();
		$this -> FormLabel -> amount = new stdClass();
	}
	
	/**
	 * Возвращает форму для формирования платежа
	 *
	 * @return string
	 */
	public function getForm()
	{
		$Phtml = new View("./library/pays/liqpay/view/form.phtml");
		$Phtml -> Pay = $this;

		return $Phtml -> getView();
	}
	
	/**
	 * Формируем фомрму для оплаты и перехода на сайт LiqPAY
	 *
	 * @return string
	 */
	public function getConfirmForm()
	{
		$Phtml = new View("./library/pays/liqpay/view/confirm_form.phtml");
		$Phtml -> form_title 			= $this -> name;
		$Phtml -> encode_operation_xml 	= $this -> encode_operation_xml;
		$Phtml -> encode_signature 		= $this -> encode_signature;
		
		return $Phtml -> getView();
	}
	
	/**
	 * Кодирует поля формы
	 *
	 */
	public function encodeFormFields()
	{
$xml="<request>      
		<version>1.2</version>
		<merchant_id>".$this -> OperationXml -> merchant_id."</merchant_id>
		<result_url>".$this -> OperationXml -> result_url."</result_url>
		<server_url>".$this -> OperationXml -> server_url."</server_url>
		<order_id>".$this -> OperationXml -> order_id."</order_id>
		<amount>".$this -> OperationXml -> amount."</amount>
		<currency>".$this -> OperationXml -> currency."</currency>
		<description>".Str::transRuToEn($this -> OperationXml -> description)."</description>
		<default_phone>".$this -> OperationXml -> default_phone."</default_phone>
		<pay_way>".$this -> OperationXml -> pay_way."</pay_way>
		<goods_id></goods_id>
</request>";
			
		/*Кодируем наш XML файл*/
		$this -> encode_operation_xml 	= base64_encode($xml);
		 /*Формируем подпись*/
		$this -> encode_signature 		= base64_encode(sha1($this -> OperationXml -> signature.$xml.$this -> OperationXml -> signature,1));
	}
	
	/**
	 * Декодирует поля формы
	 *
	 */
	public function decodeFormFields()
	{
		//Декодируем данные
		$this -> decode_operation_xml 	= base64_decode($this -> encode_operation_xml);
		
		//Сохраняем полученные данные operation_xml в ХМЛ поле
		$this -> OperationXml -> XML = XML::getObj($this -> decode_operation_xml,false);
	}
	
	/**
	 * Проверяем достоверность полученных данных
	 *
	 */
	public function checkSuccess()
	{
		if(!$this -> decode_operation_xml)
		{
			$this -> decodeFormFields();
		}
		
		$signature = base64_encode(sha1($this -> OperationXml -> signature.$this -> decode_operation_xml.$this -> OperationXml -> signature,1));
		
		if($signature == $this -> encode_signature)
		{
			return true;
		}
		return false;
	}
	
	/**
	 * Воозвращает описание данных в виде массива
	 *
	 * @param string $doc_str 
	 */
	public function getDescriptionObj($doc_str = NULL)
	{
		$data_ar = array(
			'version' => array('title' => Lng::_('Версия скрипта оплаты')),
			'action' => array('title' => Lng::_('Способ ответа <small>(result_url, server_url)</small>')),
			'merchant_id' => array('title' => Lng::_('ID мерчанта')),
			'order_id' => array('title' => Lng::_('ID транзакции этой системы')),
			'amount' => array('title' => Lng::_('Сумма транзакции')),
			'currency' => array('title' => Lng::_('Валюта транзакции <small>(USD, EUR, UAH, RUR)</small>')),
			'description' => array('title' => Lng::_('Описание транзакции')),
			'status' => array('title' => Lng::_('Статус транзакции <small>(success, failure, wait_secure)</small>')),
			'transaction_id' => array('title' => Lng::_('ID транзакции в системе LiqPay')),
			'pay_way' => array('title' => Lng::_('Способ оплаты <small>(card, liqpay)</small>')),
			'sender_phone' => array('title' => Lng::_('Телефон плательщика')),
			'_PAY_COOMENT' => array('title' => ''),
		);
		
		try
		{
			//Парсим данные
			$XMLDoc = XML::getObj($doc_str,false);
			
			if(sizeof($XMLDoc))
			{
				foreach($data_ar as $key => $val)
				{
					$data_ar[$key]['value'] = (string)$XMLDoc -> $key;
				}
			}
		}
		catch (Exception $e){	}
		
		return $data_ar;
	}
	
	/**
	 * Проверяет правельность телефона
	 *
	 */
	public function preparePhone($phone=0)
	{
		//Удаляем все кроме цифр
		return "+".preg_replace("/\D*/i","",$phone);
	}
}