<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс системы принятия платежей robokassa  
 */

class Pays_Robokassa_Pay
{
	/**
	 * Название платежной системы
	 *
	 * @var string
	 */
	public $name = "Система приема платежей Robokassa";
	
	/**
	 * Краткое название платежной системы
	 *
	 * @var string
	 */
	public $name_short = "Robokassa";
	
	/**
	 * Код платежной системы
	 *
	 * @var string
	 */
	public $code = "Robokassa";
	
	/**
	 * Ссылка на сайт
	 *
	 * @var string
	 */
	public $site = "http://robokassa.ru/";
	
	/**
	 * Описание
	 *
	 * @var string
	 */
	public $description = "ROBOKASSA — это сервис, позволяющий Продавцам (интернет-магазинам, поставщикам услуг) принимать платежи от клиентов.";
	
	/**
	 * Путь к логотипу платежной системы
	 *
	 * @var string
	 */
	public $path_logo = "/library/pays/robokassa/images/logo.png";

	
	/**
	 * Action формы
	 *
	 * @var string
	 */
	public $form_action = NULL;
	
	/**
	 * Объект дополнительных полей
	 *
	 * @var object
	 */
	public $FormItem = NULL;
	
	/**
	 * Login магазина в обменном пункте(обязательный параметр)
	 *
	 * @var string
	 */
	public $mrch_login = NULL;

	/**
	 * Требуемая к получению сумма(обязательный параметр). Формат представления числа - разделитель точка. 
	 * Сумма должна быть указана в той валюте, которая была указана при регистрации магазина, как валюта текущего баланса Продавца или как электронная валюта, в которой будет получать средства Продавец.
	 *
	 * @var string
	 */
	public $out_sum = NULL;
	
	/**
	 * Номер счета в магазине (должен быть уникальным для магазина). Может принимать значения от 1 до 2147483647 (2^31-1).
	 * Если содержит пустое значение, вовсе не указан, либо равен "0", то при создании операции ей будет автоматически присвоен уникальный номер счета. Рекомендуется использовать данную возможность только в очень простых магазинах, где не требуется какого-либо контроля.
	 *
	 * @var string
	 */
	public $inv_id = NULL;
	
	/**
	 * Описание покупки, можно использовать только символы английского или русского алфавита, цифры и знаки препинания. Максимальная длина 100 символов.
	 *
	 * @var string
	 */
	public $desc = NULL;
	
	/**
	 * Контрольная сумма MD5(обязательный параметр)
	 *
	 * @var string
	 */
	public $signature_value = NULL;
	
	/**
	 * Предлагаемая валюта платежа. Пользователь может изменить ее в процессе оплаты.
	 *
	 * @var string
	 */
	public $inc_curr_label = NULL;
	
	/**
	 * Опционально, язык общения с клиентом. Значения: en, ru. Если не установлен - берется язык региональных установок браузера.
	 *
	 * @var string
	 */
	public $culture = NULL;
	
	/**
	 * Первый пароль
	 *
	 * @var string
	 */
	public $mrh_pass1 = NULL;

	/**
	 * Второй пароль
	 *
	 * @var string
	 */
	public $mrh_pass2 = NULL;
	
	/**
	 * Режим тестирования (1) или рабочий режим (0)
	 *
	 * @var int
	 */
	public $is_testing = 0;
	
	/**
	 * Конструктор класса
	 *
	 */
	public function __construct()
	{
		$this -> FormItem = new stdClass();
	}
	
	/**
	 * Форма перевода платежа
	 *
	 * @return string
	 */
	public function getForm()
	{
		return View::get('./library/pays/robokassa/view/form',array(
			'Pay' => $this
		));
	}
	
	/**
	 * Форма подтверждения перевода платежа
	 *
	 * @return string
	 */
	public function getConfirmForm()
	{
		return View::get('./library/pays/robokassa/view/confirm_form',array(
			'Pay' => $this
		));
	}
	
	/**
	 * Создает проверочный ключ данных, для отправки данных
	 *
	 * @return string
	 */
	public function getSendSignHash()
	{
		return md5(
			$this -> mrch_login.':'.
			$this -> out_sum.':'.
			$this -> inv_id.':'.
			$this -> mrh_pass1
		);
	}

	/**
	 * Создает проверочный ключ данных, для получения Result данных
	 *
	 * @return string
	 */
	public function getResultSignHash()
	{
		return strtoupper(md5(
			$this -> out_sum.':'.
			$this -> inv_id.':'.
			$this -> mrh_pass2
		));
	}

	/**
	 * Создает проверочный ключ данных, для получения Success данных
	 *
	 * @return string
	 */
	public function getSuccessSignHash()
	{
		return strtoupper(md5(
			$this -> out_sum.':'.
			$this -> inv_id.':'.
			$this -> mrh_pass1
		));
	}
	
	/**
	 * Обрабатывает Result данные полученные с сервера
	 *
	 */
	public function prepareResultData()
	{
		$this -> out_sum 		= $_REQUEST['OutSum'];
		$this -> inv_id 		= $_REQUEST['InvId'];
		$this -> signature_value= $_REQUEST['SignatureValue'];
	}
	
	/**
	 * Обрабатывает Success данные полученные с сервера
	 *
	 */
	public function prepareSuccessData()
	{
		$this -> culture	= $_REQUEST['Culture'];
		$this -> prepareResultData();
	}
	
	/**
	 * Обрабатывает Fail данные полученные с сервера
	 *
	 */
	public function prepareFailData()
	{
		$this -> prepareSuccessData();
	}
	
	/**
	 * Проверяет соответствие полученных данных с контрольной суммой сервера при Result данных
	 *
	 * @return bool
	 */
	public function checkResultSignHash()
	{
		return ($this -> getResultSignHash() === $this -> signature_value);
	}

	/**
	 * Проверяет соответствие полученных данных с контрольной суммой сервера при Success данных
	 *
	 * @return bool
	 */
	public function checkSuccessSignHash()
	{
		return ($this -> getSuccessSignHash() === $this -> signature_value);
	}
	
	/**
	 * Воозвращает описание данных в виде массива
	 *
	 * @param string $doc_str 
	 */
	public function getDescriptionObj($doc_str=null)
	{
		$data_ar = array(
			'OutSum' => array('title' => Lng::_('Полученная сумма')),
			'InvId' => array('title' => Lng::_('Номер счета на сайте')),
			'SignatureValue' => array('title' => Lng::_('контрольная сумма MD5')),
			'_PAY_COOMENT' => array('title' => ''),
		);
		
		//Парсим данные
@		$doc_ar = unserialize($doc_str);
		if($doc_ar && sizeof($doc_ar))
		{
			foreach($doc_ar as $key => $val)
			{
				$data_ar[$key]['value'] = $val;
			}
		}
		
		return $data_ar;
	}
}