<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс платежной системы LiqPAY  
 */

class Pays_WebMoney_Pay
{
	/**
	 * Название платежной системы
	 *
	 * @var string
	 */
	public $name = "WebMoney - система расчетов on-line";
	
	/**
	 * Краткое название платежной системы
	 *
	 * @var string
	 */
	public $name_short = "WebMoney";
	
	/**
	 * Код платежной системы
	 *
	 * @var string
	 */
	public $code = "WebMoney";
	
	/**
	 * Ссылка на сайт
	 *
	 * @var string
	 */
	public $site = "http://www.webmoney.ru";
	
	/**
	 * Описание
	 *
	 * @var string
	 */
	public $description = "WebMoney — это универсальное средство для расчетов в Сети, целая среда финансовых взаимоотношений, которой сегодня пользуются миллионы людей по всему миру.";
	
	/**
	 * Путь к логотипу платежной системы
	 *
	 * @var string
	 */
	public $path_logo = "/library/pays/webmoney/images/logo.png";

	
	/**
	 * Action формы
	 *
	 * @var string
	 */
	public $form_action = NULL;
	
	/**
	 * Объект дополнительных полей
	 *
	 * @var object
	 */
	public $FormItem = NULL;
	
	
	/**
	 * Сумма платежа
	 *
	 * @var double
	 */
	public $lmi_payment_amount;
	
	/**
	 * Внутренний номер покупки продавца
	 *
	 * @var string
	 */
	public $lmi_payment_no;
	
	/**
	 * Кошелек продавца
	 *
	 * @var string
	 */
	public $lmi_payee_purse;
	
	/**
	 * Флаг тестового режима (0/1)
	 *
	 * @var int
	 */
	public $lmi_mode;
	
	/**
	 * Внутренний номер счета в системе WebMoney Transfer
	 *
	 * @var int
	 */
	public $lmi_sys_invs_no;
	
	/**
	 * Внутренний номер платежа в системе WebMoney Transfer
	 *
	 * @var int
	 */
	public $lmi_sys_trans_no;
	
	/**
	 * Кошелек, с которого покупатель совершил платеж
	 *
	 * @var string
	 */
	public $lmi_payer_purse;
	
	/**
	 * WM-идентификатор покупателя, совершившего платеж
	 *
	 * @var int
	 */
	public $lmi_payer_wm;
	
	/**
	 * Дата и время реального прохождения платежа в системе WebMoney Transfer в формате "YYYYMMDD HH:MM:SS"
	 *
	 * @var string
	 */
	public $lmi_sys_trans_date;
	
	/**
	 * Комментарий к платежу
	 *
	 * @var string
	 */
	public $lmi_payment_desc;
	
	/**
	 * Контрольная подпись MD5, 32-битная сумма полученных данных
	 *
	 * @var string
	 */
	public $lmi_hash;
	
	/**
	 * Секретный ключ
	 *
	 * @var string
	 */
	public $lmi_secret_key;
	
	/**
	 * Конструктор класса
	 *
	 */
	public function __construct()
	{
		$this -> FormItem = new stdClass();
	}
	
	/**
	 * Форма перевода платежа
	 *
	 * @return string
	 */
	public function getForm()
	{
		return View::get('./library/pays/webmoney/view/form',array(
			'Pay' => $this
		));
	}
	
	/**
	 * Форма подтверждения перевода платежа
	 *
	 * @return string
	 */
	public function getConfirmForm()
	{
		return View::get('./library/pays/webmoney/view/confirm_form',array(
			'Pay' => $this
		));
	}
	
	
	/**
	 * Создает проверочный ключ полученных данных с сервера
	 *
	 */
	public function getSignHash()
	{
		return strtoupper(md5($this -> lmi_payee_purse.
		            	$this -> lmi_payment_amount.
			            $this -> lmi_payment_no.
			            $this -> lmi_mode.
			            $this -> lmi_sys_invs_no.
			            $this -> lmi_sys_trans_no.
			            $this -> lmi_sys_trans_date.
			            $this -> lmi_secret_key.
			            $this -> lmi_payer_purse.
			            $this -> lmi_payer_wm));
	}
	
	/**
	 * Обрабатывает Result данные полученные с сервера
	 *
	 */
	public function prepareResultData()
	{
		$this -> lmi_payee_purse 	= $_REQUEST['LMI_PAYEE_PURSE'];
		$this -> lmi_payment_amount = $_REQUEST['LMI_PAYMENT_AMOUNT'];
		$this -> lmi_payment_no 	= $_REQUEST['LMI_PAYMENT_NO'];
		$this -> lmi_mode 			= $_REQUEST['LMI_MODE'];
		$this -> lmi_sys_invs_no 	= $_REQUEST['LMI_SYS_INVS_NO'];
		$this -> lmi_sys_trans_no 	= $_REQUEST['LMI_SYS_TRANS_NO'];
		$this -> lmi_sys_trans_date = $_REQUEST['LMI_SYS_TRANS_DATE'];
		$this -> lmi_payer_purse 	= $_REQUEST['LMI_PAYER_PURSE'];
		$this -> lmi_payer_wm 		= $_REQUEST['LMI_PAYER_WM'];
		$this -> lmi_hash 			= $_REQUEST['LMI_HASH'];
	}
	
	/**
	 * Обрабатывает Success данные полученные с сервера
	 *
	 */
	public function prepareSuccessData()
	{
		$this -> lmi_payment_no 	= $_REQUEST['LMI_PAYMENT_NO'];
		$this -> lmi_sys_invs_no 	= $_REQUEST['LMI_SYS_INVS_NO'];
		$this -> lmi_sys_trans_no 	= $_REQUEST['LMI_SYS_TRANS_NO'];
		$this -> lmi_sys_trans_date = $_REQUEST['LMI_SYS_TRANS_DATE'];
	}
	
	/**
	 * Обрабатывает Fail данные полученные с сервера
	 *
	 */
	public function prepareFailData()
	{
		$this -> prepareSuccessData();
	}
	
	/**
	 * Проверяет соответствие полученных данных с контрольной суммой сервера
	 *
	 * @return bool
	 */
	public function checkSignHash()
	{
		//echo "{$this -> getSignHash()} === {$this-> lmi_hash}";
		return ($this -> getSignHash() === $this-> lmi_hash);
	}
	
	/**
	 * Воозвращает описание данных в виде массива
	 *
	 * @param string $doc_str 
	 */
	public function getDescriptionObj($doc_str = NULL)
	{
		$data_ar = array(
			'LMI_PAYEE_PURSE' => array('title' => Lng::_('Кошелек продавца')),
			'LMI_PAYMENT_AMOUNT' => array('title' => Lng::_('Сумма платежа')),
			'LMI_PAYMENT_NO' => array('title' => Lng::_('Внутренний номер покупки продавца')),
			'LMI_MODE' => array('title' => Lng::_('Флаг тестового режима <small>(0 - рабочий режим, 1 - тестовый режим</small>)')),
			'LMI_SYS_INVS_NO' => array('title' => Lng::_('Внутренний номер счета в системе WebMoney Transfer')),
			'LMI_SYS_TRANS_NO' => array('title' => Lng::_('Внутренний номер платежа в системе WebMoney Transfer')),
			'LMI_PAYER_PURSE' => array('title' => Lng::_('Кошелек покупателя')),
			'LMI_PAYER_WM' => array('title' => Lng::_('WMId покупателя')),
			'LMI_HASH' => array('title' => Lng::_('Контрольная подпись')),
			'LMI_SYS_TRANS_DATE' => array('title' => Lng::_('Дата и время выполнения платежа <small>(YYYYMMDD HH:MM:SS)</small>')),
			'LMI_PAYMENT_DESC' => array('title' => Lng::_('Примечание к платежу')),
			'_PAY_COOMENT' => array('title' => ''),
		);
		
		//Парсим данные
@		$doc_ar = unserialize($doc_str);
		if($doc_ar && sizeof($doc_ar))
		{
			foreach($doc_ar as $key => $val)
			{
				$data_ar[$key]['value'] = $val;
			}
		}
		
		return $data_ar;
	}
}