<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Библиотека работы с кэшем
 */

//Подключаем библиотеку CACHE_LITE
include_once ('./library/php/vendor/cache/cache_lite/Lite.php');

class CacheFile
{
	/**
	 * Группа конфигурации по умолчанию
	 *
	 * @var string
	 */
	private $cnf_group = 'default';
	
	/**
	 * Объект кэширования данных
	 *
	 * @var objert
	 */
	private $Cache_Lite;
	
	/**
	 * Конструктор класса
	 *
	 * @param string настройка группы кэширования
	 */
	public function __construct($cnf_group = NULL)
	{
		$this -> cnf_group = $cnf_group;
		$this -> init();
	}
	
	/**
	 * Возвращает объект
	 *
	 * @return object
	 */
	public static function instance($cnf_group = 'default')
	{
		static $Instance;
		
		if(isset($Instance[$cnf_group]) == FALSE)
		{
			$Instance[$cnf_group] = new self($cnf_group);
		}
		
		return $Instance[$cnf_group];
	}
	
	/**
	 * Метод инициализации данных по умолчанию
	 *
	 */
	public function init()
	{
		try
		{
			$cnf_ar = Helper_Config::loadFile('./library/config/cache.php');
			$this -> Cache_Lite = new Cache_Lite($cnf_ar[$this -> cnf_group]);
		}
		catch (Exception $e)
		{
			throw new Exception();
		}
	}
	
	/**
	 * Устанавливает данные кэширования
	 *
	 * @param string $id
	 * @param int $lifeTime
	 * @param string $group
	 * @param bool $doNotTestCacheValidity
	 * @return mixed
	 */
	public function get($id = 'key', $lifeTime = 3600, $group = 'default', $doNotTestCacheValidity = FALSE)
	{
		$this -> Cache_Lite -> setLifeTime($lifeTime);
		return $this -> Cache_Lite -> get($id, $group, $doNotTestCacheValidity);
	}
	
	/**
	 * Устанавливает данные кэширования
	 *
	 * @param string $data
	 * @param string $id
	 * @param string $group
	 */
	public function set($data, $id = 'key', $group = 'default')
	{
		$this -> Cache_Lite -> save($data, $id, $group);
	}
	
	/**
	 * Удаляет кэш
	 *
	 * @param string $id
	 * @param string $group
	 * @param bool $checkbeforeunlink
	 */
	public function remove($id, $group = 'default', $checkbeforeunlink = false)
	{
		$this -> Cache_Lite -> remove($id, $group, $checkbeforeunlink);
	}
	
	/**
	 * Удаляет кэш группы
	 *
    * @param string $group name of the cache group
    * @param string $mode flush cache mode : 'old', 'ingroup', 'notingroup', 
    *                                        'callback_myFunction'
    * @return boolean true if no problem
	 */
    function clean($group = false, $mode = 'ingroup')
    {
        $this -> Cache_Lite -> clean($group, $mode);
    }
}