<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс работы с категориями
 */

class Category
{
	
	/**
	 * В рекурсии формирует дерево из массива
	 *
	 * @param array $data_ar массив данных дерева (двухмерный)
	 * @param int $start_id стартовое id массива, т.е. id с которого начнется формирование дерева
	 * @param int $padding_left отступ
	 * @param int $prefix префикс для заголовка
	 * @param array $new_data_ar новый массив дерева (одномерный)
	 * @return array
	 */
	public static function createTree($data_ar,$start_id=0,$padding_left=0,$prefix=null,$new_data_ar=array())
	{
		if(isset($data_ar[$start_id]))
		{
			foreach($data_ar[$start_id] as $category_id => $title)
			{
				$padding_str = '';
				if($padding_left)
				{
					for($i = 0; $i <= $padding_left; $i++)
					{
						$padding_str = $padding_str.'&nbsp;';
					}
					$title = $padding_str.$prefix.$title;
				}
				else 
				{
					$title = $padding_str.$title;
				}
				$padding_str = '';
				$new_data_ar[$category_id] = $title;
				if(isset($data_ar[$start_id][$category_id]))
				{
					$new_data_ar = self::createTree($data_ar,$category_id,$padding_left+5,$prefix,$new_data_ar);
				}
			}
		}
		
		return $new_data_ar;
	}
	
	/**
	 * В рекурсии формирует дерево в виде отступов из массива
	 *
	 * @param array $data_ar массив данных дерева (двухмерный)
	 * @param int $start_id стартовое id массива, т.е. id с которого начнется формирование дерева
	 * @param int $padding_left отступ
	 * @param array $new_data_ar новый массив дерева (одномерный)
	 * @return array
	 */
	public static function createPadding($data_ar,$start_id=0,$padding_left=0,$prefix=null,$new_data_ar=array())
	{
		if(isset($data_ar[$start_id]))
		{
			foreach($data_ar[$start_id] as $category_id => $title)
			{
				$padding_str = '';
				if($padding_left)
				{
					for($i = 0; $i <= $padding_left; $i++)
					{
						$padding_str = $padding_str.'&nbsp;';
					}
				}
				$new_data_ar[$category_id] = $padding_str;
				if(isset($data_ar[$start_id][$category_id]))
				{
					$new_data_ar = self::createPadding($data_ar,$category_id,$padding_left+5,$prefix,$new_data_ar);
				}
			}
		}
		
		return $new_data_ar;
	}
	
	/**
	 * Формирует списки 
	 *
	 * @param array $data_ar массив данных дерева
	 * @param int $start_id id корень 
	 * @param string $url_prefix префикс URL
	 * @param string $str_list 
	 * @return string
	 */
	public static function createListTree($data_ar,$start_id=0,$url_prefix=null,$str_list=null)
	{
		if(isset($data_ar[$start_id]))
		{
			$str_list = '';
			foreach($data_ar[$start_id] as $data_id => $title)
			{
				if(isset($data_ar[$data_id]))
				{
					$str_list .= '<li><span class="folder"><a href="'.URL::_($url_prefix.$data_id).'">'.$title.'</a></span><ul>';
					$str_list .= self::createListTree($data_ar,$data_id,$url_prefix,$str_list);
					$str_list .= '</ul></li>';
				}
				else 
				{
					$str_list .= '<li><span class="file"><a href="'.URL::_($url_prefix.$data_id).'">'.$title.'</a></span></li>';
				}
			}
		}
		
		return $str_list;
	}
	
	
	/**
	 * Получает часть дерева с $start_id по глубину $depth
	 *
	 * @param array $data_ar массив дерева
	 * @param int $start_id с id какой ветви начать отсчет
	 * @param int $depth глбина по которую нужно получить дерево
	 * @param int $cur_depth
	 * @param array $new_data_ar
	 * @return array
	 */
	public static function getTreeByDepth($data_ar=array(),$start_id=0,$depth=0,$cur_depth=0,$new_data_ar=array())
	{
		if($cur_depth >= $depth){return $new_data_ar;}

		if(isset($data_ar[$start_id]))
		{
			foreach($data_ar[$start_id] as $data_id => $val)
			{
				$new_data_ar[$start_id][$data_id] = $val;
				if(isset($data_ar[$data_id]))
				{
					$new_data_ar = self::getTreeByDepth($data_ar,$data_id,$depth,$cur_depth+1,$new_data_ar);
				}
			}
		}
		return $new_data_ar;
	}
	
	
	/**
	 * Формирует pathway в виде строки
	 *
	 * @param array $data_ar массив в виде дерева
	 * @param int $start_id ветвь с которой нужно отсчитывать
	 * @param string $url_prefix префикс ссылки, если нужно
	 * @param string $attribute_ar массив дополнительных атрибутов
	 * @param string $pathway сформированный путь
	 * @return string
	 */
	public static function getPathWayStr($data_ar=array(),$start_id=0,$url_prefix=null,$attribute_ar=array(),$pathway=null)
	{
		foreach($data_ar as $data_id => $val_ar)
		{
			if(isset($val_ar[$start_id]))
			{
				if($url_prefix)
				{
					//$pathway = "<div class='bred' itemscope itemtype='http://data-vocabulary.org/Breadcrumb'><a href=\"".URL::_($url_prefix.$start_id, $val_ar[$start_id])."\"".Str::arrayToAtribute($attribute_ar)."><span itemprop='title'>".$val_ar[$start_id]."</span></a></div> &raquo; ".$pathway;
					
					$pathway = '<div class="bred" itemscope itemtype="http://data-vocabulary.org/Breadcrumb"><a href="'.URL::_($url_prefix.$start_id, $val_ar[$start_id]).'"'.Str::arrayToAtribute($attribute_ar).'><span itemprop="title">'.$val_ar[$start_id].'</span></a></div> &raquo; '.$pathway;
					
				}
				else
				{
					$pathway = $val_ar[$start_id]." &raquo; ".$pathway;	
				}
				$pathway = self::getPathWayStr($data_ar,$data_id,$url_prefix,$attribute_ar,$pathway);
			}
		}
		return $pathway;
	}
	
	
	/**
	 * Формирует pathway БЛЯ ДЛЯ СПИСКА ОБЪЯВЛЕНИЙ
	 *
	 * @param array $data_ar массив в виде дерева
	 * @param int $start_id ветвь с которой нужно отсчитывать
	 * @param string $url_prefix префикс ссылки, если нужно
	 * @param string $attribute_ar массив дополнительных атрибутов
	 * @param string $pathway сформированный путь
	 * @return string
	 */
	public static function getPathWayPiz($data_ar=array(),$start_id=0,$url_prefix=null,$attribute_ar=array(),$pathway=null)
	{
		foreach($data_ar as $data_id => $val_ar)
		{
			if(isset($val_ar[$start_id]))
			{
				if($url_prefix)
				{
					$pathway = "<a href=\"".URL::_($url_prefix.$start_id, $val_ar[$start_id])."\"".Str::arrayToAtribute($attribute_ar).">".$val_ar[$start_id]."</a> &raquo; ".$pathway;
				}
				else
				{
					$pathway = $val_ar[$start_id]." &raquo; ".$pathway;	
				}
				$pathway = self::getPathWayPiz($data_ar,$data_id,$url_prefix,$attribute_ar,$pathway);
			}
		}
		return $pathway;
	}
	
	/**
	 * Формирует pathway в виде массива
	 *
	 * @param array $data_ar массив в виде дерева
	 * @param int $start_id ветвь с которой нужно отсчитывать
	 * @param string $pathway_ar массив с элементов пути 
	 * @return array
	 */
	public static function getPathWayAr($data_ar=array(),$start_id=0,$pathway_ar=array())
	{
		foreach($data_ar as $data_id => $val_ar)
		{
			if(isset($val_ar[$start_id]))
			{
				$pathway_ar[$start_id] = $val_ar[$start_id];
				$pathway_ar = self::getPathWayAr($data_ar,$data_id,$pathway_ar);
			}
		}
		return $pathway_ar;
	}
}