<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс проверки данных
 */
 
class CheckData
{
	/**
	 * Проверяет являются ли данные массивом с информацией
	 *
	 * @param array $data_ar массив данных
	 * @param string $message сообщение
	 * @param int $code код сообщения
	 */
	public static function existsDataArray($data_ar=array(),$message=null,$code=1)
	{
		if(!is_array($data_ar) || !sizeof($data_ar))
		{
			throw new Exception_CheckData($message,$code);
		}
	}
	
	/**
	 * Проверяет являются ли данные объектом с информацией
	 *
	 * @param object $DataAr объект данных
	 * @param string $message сообщение
	 * @param int $code код сообщения
	 */
	public static function existsDataObject($DataAr=array(),$message=null,$code=1)
	{
		if(!is_object($DataAr) || !sizeof($DataAr))
		{
			throw new Exception_CheckData($message,$code);
		}
	}
	
	/**
	 * Проверяет наличие указанных GET и POST данных 
	 *
	 * @param array $get_ar GET массив 
	 * @param array $post_ar POST массив 
	 * @param string $message сообщение
	 * @param int $code код сообщения
	 */
	public static function existsRequest($get_ar=array(),$post_ar=array(),$message=null,$code=1)
	{
		if(is_array($get_ar) && sizeof($get_ar))
		{
			foreach($get_ar as $index)
			{
				if(!isset($_GET[$index]))
				{
					throw new Exception_CheckData($message,$code);
				}
			}
		}
		if(is_array($post_ar) && sizeof($post_ar))
		{
			foreach($post_ar as $index)
			{
				if(!isset($_POST[$index]))
				{
					throw new Exception_CheckData($message,$code);
				}
			}
		}
	}
	
	/**
	 * Проверка почтового ящика
	 *
	 * @param string $email
	 */
	public static function email($email)
	{
		if(!preg_match('|^[a-z0-9_\-\.]+@[a-z0-9\-]+\.[a-z0-9_\-\.]+$|i',$email))
		{
			throw new Exception_CheckData(Lng::_('Не правильный формат почтового ящика. Пример ввода ящика - some_email@gmail.com'),1);
		}
	}
	
	/**
	 * Проверяет, данные получены Аякс способом или нет
	 *
	 */
	public static function isAjax($is_exception = TRUE)
	{
		if(!isset($_SERVER['HTTP_X_REQUESTED_WITH']) || $_SERVER['HTTP_X_REQUESTED_WITH'] != 'XMLHttpRequest')
		{
			if($is_exception == TRUE)
			{
				throw new Exception_Ajax(Lng::_('Для корректной работы сайта, включите JavaScript'),1);
			}
			return FALSE;
		}
		return TRUE;
	}

	/**
	 * Проверяет капчу
	 *
	 * @param string $check_access код капчи
	 * @return bool
	 */
	public static function captcha($check_access=0)
	{
		if(isset($_SESSION['captcha_keystring']) && $check_access == $_SESSION['captcha_keystring'])
		{
			return TRUE;
		}
		return FALSE;
	}
}