<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Файл, содержит класс API БД
 */

/**
 * Класс подключения к БД Mysql
 *
 */
class DBMysql
{
	/**
	 * Имя пользователя
	 *
	 * @var string
	 */
	private $user;
	/**
	 * Пароль пользователя
	 *
	 * @var string
	 */
	private $pass;
	/**
	 * Хост
	 *
	 * @var string
	 */
	private $dbhost;
	/**
	 * Название базы данных
	 *
	 * @var string
	 */
	private $dbname;
	/**
	 * Дескриптор подключения к базе данных
	 *
	 * @var resource
	 */
	private $dbh;
	
	/**
	 * Префикс таблиц БД
	 *
	 * @var string
	 */
	private $prefix;
	
	/**
	 * Количество выполненных запросов к БД
	 *
	 * @var int
	 */
	private static $count_query = 0;
	
	/**
	 * История запросов к БД
	 *
	 * @var array
	 */
	private static $query_history_ar = array();
	/**
	 * Конструктор класса, устанавливает основные параметры
	 *
	 * @param string $user имя пользователя
	 * @param string $pass пароль пользователя
	 * @param string $dbhost хост
	 * @param string $dbname название базы данных
	 * @param string $prefix название базы данных
	 * @return BD_Mysql
	 */
	function __construct($user, $pass, $dbhost, $dbname, $prefix)
	{
		$this -> user 	= $user;
		$this -> pass 	= $pass;
		$this -> dbhost = $dbhost;
		$this -> dbname = $dbname;
		$this -> prefix = $prefix;
		
		if($this -> dbname)
		{
			$this -> setConnect();
		}
	}
	
	/**
	 * Производит соединение с БД
	 *
	 */
	private function setConnect()
	{
@		$this -> dbh = mysql_connect($this -> dbhost, $this -> user, $this -> pass);
		if(!is_resource($this -> dbh))
		{
			throw new Exception_DB("Error connecting to database");
		}
		if(!mysql_select_db($this -> dbname,$this -> dbh))
		{
			throw new Exception_DB("Database not found");
		}
		$this -> setQuery("SET NAMES UTF8");
	}
	
	/**
	 * Выполняет запрос к БД
	 *
	 * @param string $query sql запрос
	 * @param string $messae сообщение при ошибке
	 * @param string $method метод приминяемый к resourse 
	 * @return object|resourse
	 */
	public function setQuery($query = NULL, $messae = NULL, $method = FALSE)
	{
		if(!is_resource($this -> dbh))
		{
			$this -> setConnect();
		}
		$query = $this -> replacePrefix($query);
		
		self::$query_history_ar[] = (self::$count_query+1).") ".$query;
		
		if(!$result = mysql_query($query,$this -> dbh))
		{
			if(Registry::get('is_debug') == 0)
			{
				throw new Exception_DB($messae);
			}
			else 
			{
				throw new Exception_DB($messae.'<br><br><i>'.$this -> error().'</i>');
			}
		}
		self::$count_query++;
		if($method)
		{
			if(method_exists($this, $method))
			{
				return $this -> $method($result);
			}
			return $this -> getObject($result);
		}
		return $result;
	}
	
	/**
	 * Получаем объект данных из БД
	 *
	 * @param resource $result ресурс запроса
	 * @return array
	 */	
	public function getObject($result)
	{
		return @mysql_fetch_object($result);
	}
	
	/**
	 * Получает количество рядов в результате
	 *
	 * @param resource $result дескриптор запроса
	 * @return int
	 */
	public function getCount($result)
	{
		return @mysql_num_rows($result);
	}
	
	/**
	 * Получает id, сгенерированный предыдущей операцией INSERT 
	 *
	 * @return int
	 */
	public function getLastId()
	{
		if(!is_resource($this -> dbh))
		{
			throw new Exception_DB("Error connecting to database");
		}
		return @mysql_insert_id($this -> dbh);
	}

	/**
	 * Закрывает соединение с БД
	 *
	 * @return boolean
	 */
	public function close()
	{
		if(!is_resource($this -> dbh))
		{
			$result = @mysql_close($this -> dbh);
		}
		return $result;
	}

	/**
	 * Выводит ошибки
	 *
	 * @return array
	 */
	public function error()
	{
		$result	 = @mysql_error($this -> dbh);
		$result	.= @mysql_errno($this -> dbh);

		return $result;
	}
	
	/**
	 * Возвращает количество выполненых запросов к БД
	 *
	 * @return int
	 */
	public function getCountQuery()
	{
		return self::$count_query;
	}

	/**
	 * Возвращает историю выполненных запросов к БД
	 *
	 * @return array
	 */
	public function getQueryHistory()
	{
		return self::$query_history_ar;
	}
	
	
	/**
	 * This function replaces a string identifier <var>$prefix</var> with the
	 * string held is the <var>_table_prefix</var> class variable.
	 *
	 * @param string The SQL query
	 * @param string The common table prefix
	 * @author thede, David McKinnis
	 */
	private function replacePrefix( $sql, $prefix='#__' ) {
		$sql = trim( $sql );
		
		$escaped = false;
		$quoteChar = '';

		$n = strlen( $sql );

		$startPos = 0;
		$literal = '';
		while ($startPos < $n) {
			$ip = strpos($sql, $prefix, $startPos);
			if ($ip === false) {
				break;
			}

			$j = strpos( $sql, "'", $startPos );
			$k = strpos( $sql, '"', $startPos );
			if (($k !== FALSE) && (($k < $j) || ($j === FALSE))) {
				$quoteChar	= '"';
				$j			= $k;
			} else {
				$quoteChar	= "'";
			}

			if ($j === false) {
				$j = $n;
			}

			$literal .= str_replace( $prefix, $this-> prefix, substr( $sql, $startPos, $j - $startPos ) );
			$startPos = $j;

			$j = $startPos + 1;

			if ($j >= $n) {
				break;
			}

			// quote comes first, find end of quote
			while (TRUE) {
				$k = strpos( $sql, $quoteChar, $j );
				$escaped = false;
				if ($k === false) {
					break;
				}
				$l = $k - 1;
				while ($l >= 0 && $sql{$l} == '\\') {
					$l--;
					$escaped = !$escaped;
				}
				if ($escaped) {
					$j	= $k+1;
					continue;
				}
				break;
			}
			if ($k === FALSE) {
				// error in the query - no end quote; ignore it
				break;
			}
			$literal .= substr( $sql, $startPos, $k - $startPos + 1 );
			$startPos = $k+1;
		}
		if ($startPos < $n) {
			$literal .= substr( $sql, $startPos, $n - $startPos );
		}
		return $literal;
	}
}
