<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс копирования файлов, перемещнеия и удаления файлов
 */

class File
{
	/**
	 * Источник копирования
	 *
	 * @var string
	 */
	private $suorce;
	/**
	 * Место куда будут скопированы данные
	 *
	 * @var string
	 */
	private $destination;
	/**
	 * Массив файлов
	 *
	 * @var array
	 */
	private $file_ar = array();
	/**
	 * Массив каталогов
	 *
	 * @var array
	 */
	private $dir_ar = array();
	/**
	 * Признак того что файл был скопирован
	 *
	 * @var boolean
	 */
	private $copy_wrong_bool;
	
	/**
	 * Содержит массив допустимых расширений (файлы которых можно копировать)
	 *
	 * @var array
	 */
	private $ext_ar = array();
	
	function __construct(){	}
	
	
	/**
	 * Выполняет копирование файла
	 *
	 * @param string $source_file источник файла
	 * @param string $destination_file место назначение
	 * @return boolean
	 */
	public function fileCopy($source_file=null,$destination_file=null)
	{
		if(!$source_file || !$destination_file)
		{
			return 0;
		}
		if(!$this -> checkExtension($source_file) || !copy(realpath($source_file),$destination_file))
		{
			return 0;
		}
		return 1;
	}
	
	/**
	 * Проверяет расширение файла
	 *
	 * @param string $file путь к файлу|файл
	 * @return boolean
	 */
	private function checkExtension($file=null)
	{
		if(!count($this -> ext_ar) || !in_array(end(explode(".",$file)),$this -> ext_ar))
		{
			return 0;
		}
		return 1;
	}
	
	/**
	 * устанавливает расширения файлы которых можно копировать
	 * 
	 * @param array $ext_ar массив допустимых расширений
	 */
	public function setExtension($ext_ar=null)
	{
		$this -> ext_ar = $ext_ar;
	}
	
	/**
	 * Выполняет копирование файлов
	 *
	 * @param string $suorce источник файлов
	 * @param string $destination место куда куда будут скопированы файлы
	 */
	public function copy($suorce,$destination)
	{
		$this -> setSuorce($suorce);
		$this -> setDestination($destination);
		$this -> checkPath();
		$this -> getDataDir($this -> suorce);
		$this -> createDirs($this -> replacePath($this -> dir_ar));
		$this -> copyFilesInDirs();
	}

	/**
	 * Выполняет перемещение файлов
	 *
	 * @param string $suorce источник файлов
	 * @param string $destination место куда будут перемещены файлы
	 */
	public function movie($suorce,$destination)
	{
		$this -> copy($suorce,$destination);
		$this -> delete($suorce);
	}
	
	/**
	 * Удаляет каталог с содержимым
	 *
	 * @param string $path путь удаляемому каталогу
	 * @param bool $and_pdir определяет, удалять с родительской дирректорией или нет
	 */
	public function delete($path=null,$and_pdir=false)
	{
		$this -> deleteFiles($path);
		$this -> deleteDirs($this -> dir_ar);

		if($and_pdir)
		{
			rmdir($path);
		}
	}
	
	/**
	 * Удаляет файл
	 *
	 * @param string $file путь к файлу
	 * @return bool
	 */
	public static function deleteFile($suorce=null)
	{
		if(is_file($suorce))
		{
			return unlink($suorce);
		}
		return false;
	}
	
	
	
	/**
	 * Удаляет файлы
	 *
	 * @param array $suorce место расположение каталога с файлами
	 */
	public function deleteFiles($suorce)
	{
		if(!count($this -> file_ar))
		{
			$this -> setSuorce($suorce);
			$this -> getDataDir($this -> suorce);
		}
		if(!count($this -> file_ar)){return;}
		foreach($this -> file_ar as $file)
		{
			if(is_file($file))
			{
				unlink($file);
			}
		}
	}
	
	/**
	 * Выполняет удаление каталогов
	 *
	 * @param array $dir_ar массив каталогов
	 */
	private function deleteDirs($dir_ar)
	{
		if(!count($dir_ar)){return;}
		krsort($dir_ar);
		foreach($dir_ar as $dir)
		{
			if(is_dir($dir))
			{
				rmdir($dir);
			}
		}
	}
	
	/**
	 * Возвращает данные каталога - "источника"
	 *
	 * @param string $path путь 
	 */
	public function getDataDir($path)
	{
		$line_ar = glob($path.'*');
		if(empty($line_ar)){return;}
		foreach($line_ar as $tmp_path)
		{
			if(is_dir($tmp_path))
			{
				$this -> dir_ar[] = $tmp_path;
				$this -> getDataDir($tmp_path."/");
			}
			else 
			{
				$this -> file_ar[] = $tmp_path;
			}
		}
	}
	
	/**
	 * Выполняет частичную замену путей
	 *
	 * @param array $path массив путей
	 * @return array
	 */
	private function replacePath($path_ar)
	{
		if(!is_array($path_ar) || !count($path_ar)){return;}
		foreach($path_ar as $tmp_path)
		{
			$tmp_path_ar[] = str_replace($this -> suorce,$this -> destination, $tmp_path);
		}
		return $tmp_path_ar;
	}
	
	/**
	 * Создает каталоги
	 *
	 * @param array $dir_ar массив каталогов
	 */
	private function createDirs($dir_ar)
	{
		if(!is_array($dir_ar) || !count($dir_ar)){return;}
		foreach($dir_ar as $dir)
		{
			if(is_dir($dir))
			{
				continue;
			}
			if(ereg($this -> suorce,$dir))
			{
				continue;
			}
			
			File::createDir($dir);
		}
	}
	
	/**
	 * Выполняет копирование массива файлов
	 *
	 */
	private function copyFilesInDirs()
	{
		if(!count($this -> file_ar)){return;}
		foreach($this -> file_ar as $file)
		{
			$destination = str_replace($this -> suorce,$this -> destination,$file);
			if(is_file($destination)){continue;}
			if(sizeof($this -> ext_ar))
			{
				$this -> fileCopy($file,$destination);
			}
			else 
			{
				copy($file,$destination);
			}
		}
	}
	
	/**
	 * Устанавливает источник копирования файлов
	 *
	 * @param string $suorce источник
	 */
	private function setSuorce($suorce)
	{
		if(is_dir($suorce))
		{
			$this -> suorce = $suorce;
		}
		else 
		{
			throw new Exception("Suorce is not a directory");
		}
	}
	
	/**
	 * Устанавливает место куда будут копироваться файлы
	 *
	 * @param string $destination место куда будут копироваться файлы
	 */
	private function setDestination($destination)
	{
		if(is_dir($destination))
		{
			$this -> destination = $destination;
		}
		else 
		{
			throw new Exception("Destination is not a directory");
		}
	}
	
	/**
	 * Проверка эквивалентности путей
	 *
	 * @return null
	 */
	private function checkPath()
	{
		if($this -> suorce == $this -> destination)
		{
			throw new Exception("Error copying / moving files");
		}
	}
	
	/**
	 * Записывает данные в файл
	 *
	 * @param string $path путь к файлу
	 * @param string $data содержимое файла
	 * @param string $param дополнительный параметр
	 * @param bool $to_write устанавливает принужденную запись информации в файл (по умолчанию отключено)
	 */
	public static function write($path,$data=null,$param=null,$to_write=false)
	{
		if(is_file($path))
		{
			return file_put_contents($path,$data,$param);
		}
		if($to_write)
		{
			return file_put_contents($path,$data,$param);
		}
		
		return false;
	}
	
	/**
	 * Читает данные из файла (аналог file_get_contents)
	 *
	 * @param string $path путь к файлу
	 * @return string
	 */
	public static function read($path)
	{
		if(is_file($path))
		{
			return file_get_contents($path);
		}
		return false;
	}
	

	/**
	 * Возвращает размер каталога
	 *
	 * @param string $path путь к каталогу
	 * @param int $filesize размер дирректории 
	 * @return int
	 */
	public static function sizeDir($path,&$filesize=0)
	{
		$data = glob($path.'*');
		if(isset($data[0]))
		{
			foreach($data as $fpath)
			{
				if(is_file($fpath))
				{
					$filesize += filesize($fpath);
				}
				if(@is_dir($fpath))
				{
					File::sizeDir($fpath."/",$filesize);
				}
			}
		}
		return $filesize;
	}
	
	/**
	 * Создает каталог
	 *
	 * @param string $path
	 */
	public static function createDir($path)
	{
		if(is_dir($path) == false)
		{
			$mask = umask(0);
			mkdir($path,0777);
			umask($mask);
		}
	}
	
	/**
	 * Создаем файл
	 *
	 * @param string $path путь к создаваемому файлу
	 * @return bool
	 */
	public static function createFile($path)
	{
		return file_put_contents($path,"");
	}	
	
	/**
	 * Копирует файл index.html в указанную директорию
	 *
	 * @param string $path
	 * @return bool
	 */
	public static function copyFileIndex($path)
	{
		if(is_dir($path))
		{
			return copy("files/index.html",$path."index.html");
		}
		return false;
	}
}