<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Базовый класс Guard
 */

class Guard_Base
{
	/**
	 * Базовый файл загрузки
	 *
	 * @var string
	 */
	protected $base_file;
	
	/**
	 * Контроллер
	 *
	 * @var string
	 */
	protected $controller;
	
	/**
	 * Субконтроллер модуля
	 *
	 * @var string
	 */
	protected $sub_controller;
	
	/**
	 * Действие
	 *
	 * @var string
	 */
	protected $action;
	
	/**
	 * Подключаемый вид
	 *
	 * @var Object
	 */
	protected $view;

	/**
	 * Кэш вида
	 *
	 * @var string
	 */
	protected $cache_view = NULL;
	
	/**
	 * XML данные
	 *
	 * @var object
	 */
	protected $XMLData;

	/**
	 * Установка конфигурационных данных объекта
	 *
	 * @param unknown_type $XMLData
	 */
	function __construct($XMLData = NULL)
	{
		$this -> XMLData = $XMLData;
	}
	
	/**
	 * Устанавливает базовые параметры контроллера
	 *
	 * @param string $base_file Базовый файл загрузки
	 * @param string $controller Контроллер
	 * @param string $sub_controller субконтроллер (если нужно)
	 * @param string $action Действие
	 * @param string $target для чеговызывается (модуль, блок, пр.)
	 */
	public function setParams($base_file = NULL, $controller = NULL, $sub_controller = NULL, $action = NULL)
	{
		//Установка основных свойств контролера
		$this -> base_file 		= $base_file;
		$this -> controller 	= $controller;
		$this -> sub_controller = $sub_controller;
		$this -> action 		= $action;
	}
	
	/**
	 * Устанавливаем шаблон вида
	 *
	 * @param string $file
	 */
	public function setView($file = NULL)
	{
		$this -> _callView($file);
	}
	
	/**
	 * Устанавливает данные кэша вида
	 *
	 * @param string $data
	 */
	public function setCacheView($data = NULL)
	{
		$this -> cache_view = $data;
	}
	
	/**
	 * Возвращает вид
	 *
	 * @return object|null
	 */
	public function getView()
	{
		if($this -> cache_view == TRUE)
		{
			return $this -> cache_view;
		}
		else
		{
			if(is_object($this -> view) == TRUE && method_exists($this -> view, 'getView') == TRUE)
			{
				return $this -> view -> getView();
			}
		}
		return NULL;
	}
	
	/********************************************************************************************************************/
	/************************************************** PROTECTED METHODS ***********************************************/
	/********************************************************************************************************************/
	
	/**
	 * Возвращает библиотеку модуля
	 *
	 * @param string $lib имя библиотеки
	 * @param string $controller контроллер
	 * @return object
	 */
	protected function getLib($lib = NULL, $controller = NULL)
	{
		if(is_null($controller) && is_null($lib))
		{
			return $this -> getRegistry("Modules_".$this -> controller."_Libs_General");
		}
		else if(is_null($controller) && $lib)
		{
			return $this -> getRegistry("Modules_".$this -> controller."_Libs_".$lib);
		}
		else if($controller && is_null($lib))
		{
			return $this -> getRegistry("Modules_".$controller."_Libs_General");
		}
		else if($controller && $lib)
		{
			return $this -> getRegistry("Modules_".$controller."_Libs_".$lib);
		}
		return false;
	}
	
	/**
	 * Возвращает модель контроллера
	 *
	 * @param string $model модель
	 * @param string $controller контроллер
	 * @return object
	 */
	protected function getModel($model = NULL, $controller = NULL)
	{
		if(is_null($controller) && is_null($model))
		{
			return $this -> getRegistry("Modules_".$this -> controller."_Models_".$this -> controller);
		}
		else if(is_null($controller) && $model)
		{
			return $this -> getRegistry("Modules_".$this -> controller."_Models_".$model);
		}
		else if(is_file($controller) || strstr($controller,"/"))
		{
			return new XML($controller);
		}
		else if($controller && is_null($model))
		{
			return $this -> getRegistry("Modules_".$controller."_Models_".$controller);
		}
		else if($controller && $model)
		{
			return $this -> getRegistry("Modules_".$controller."_Models_".$model);
		}
		return false;
	}
	
	
	/**
	 * Возвращает компонент
	 *
	 * @param string $component_name имя компонента
	 * @param string $group группа (если нужно)
	 * @return object|bool
	 */
	protected function getComponent($component_name = NULL, $group = FALSE)
	{
		$Component = false;
		if(is_file("./library/components/".strtolower($component_name)."/controller.php"))
		{
			$component_str = "Components_".$component_name."_Controller";
			
			if($group)
			{
				$Component = new $component_str($group);	
			}
			else
			{
				$Component = new $component_str();
			}
		}
		
		return $Component;
	}
	
	/**
	 * Регистр объектов
	 *
	 * @param string $index индекс типа объекта (модель, библиотека)
	 * @param string $class инмя класса
	 * @return object
	 */
	protected function getRegistry($class = NULL)
	{
		static $RegistryAr;
		
		$class = strtolower($class);
		if(isset($RegistryAr[$class]))
		{
			return $RegistryAr[$class];
		}

		$Object =  new $class();
		$RegistryAr[$class] = $Object;
		
		return $Object;
	}
	
	 /**
	  * Возвращает параметры атрибута XML файла
	  *
	  */
	 protected function getParams()
	 {
	 	$Params = new stdClass();
	 	if(isset($this -> XMLData['params']))
	 	{
	 		$params_ar = explode(",",$this -> XMLData['params']);
	 		foreach($params_ar as $params)
	 		{
	 			$param_ar = explode(":",$params);
	 			$param_ar = array_map('trim', $param_ar);
	 			if(sizeof($param_ar) == 2)
	 			{
	 				$Params -> $param_ar[0] = $param_ar[1];
	 			}
	 		}
	 	}
	 	return $Params;
	 }
	 
	/**
	 * Вызывает шаблон вида
	 *
	 * @param string $file путь к файлу вида
	 */
	protected function _callView($file = NULL)
	{
		if(is_file($file))
		{
			$this -> view = new View($file);
		}
	}
}