<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс работы с почтой
 */

class Mail
{
	/**
	 * Объект класса 
	 *
	 * @var PHPMailer
	 */
	private $mail;
	
	function __construct()
	{
		$this -> mail = new PHPMailer(TRUE);
		
		$this -> mail -> CharSet = "UTF-8";
	}

	/**
	 * Устанавливает адрес отправителя
	 *
	 * @param string $email
	 * @param string $name
	 */
	public function setFromUser($email = NULL, $name = NULL)
	{
		$this -> mail -> From = $email;
		$this -> mail -> FromName = $name;
	}
	
	/**
	 * Устанавливает тему письма
	 *
	 * @param string $subject
	 */
	public function setSubject($subject = NULL)
	{
		$this -> mail -> Subject = $subject;
	}
	
	/**
	 * Устанавливает содержимое письма
	 *
	 * @param string $body
	 */
	public function setBody($body = NULL)
	{
		$this -> mail -> MsgHTML($body);
	}
	
	/**
	 * Добавляет адрес для отправки почты
	 *
	 * @param string $email
	 * @param string $name
	 */
	public function addAddress($email = NULL, $name = NULL)
	{
		try
		{
			$this -> mail -> AddAddress($email,$name);
					
		}
		catch (Exception $e)
		{
			return FALSE;			
		}
		return TRUE;
	}
	
	/**
	 * Прикрепляет файл к загрузке
	 *
	 * @param string $path_to_file путь к файлу
	 * @return bool
	 */
	public function attachFile($path_to_file = NULL)
	{
		return $this -> mail -> AddAttachment($path_to_file);
	}
	
	/**
	 * Отправляет почту
	 * @param bool $is_html определяет тип письма text или html
	 * @return bool
	 */
	public function send($is_html = TRUE)
	{
		try
		{
			$this -> mail -> IsHTML($is_html);
			//При отправки писем, в некоторых случаях могут возникать ошибки, выводимые скриптом. Подавляем их вывод
			$result = $this -> mail -> Send();
			
		}
		catch (Exception $e)
		{
			Log::add($e,"При отправке почтового сообщения возникла ошибка");
			return FALSE;			
		}
		
		return $result;
	}
	
	/********************************************************************************************************************/
	/************************************************** STATIC METHODS **************************************************/
	/********************************************************************************************************************/
	
	/**
	 * Отправляет email письмо пользователю
	 *
	 * @param string $from_name имя отправителя
	 * @param string $from_email почтовый ящик отправителя
	 * @param string $to_name имя получателя
	 * @param string $to_mail почтовый ящик получателя
	 * @param string $subject тема письма
	 * @param string $body содержимое письма
	 * @param bool $is_html отправлять письмо в  html или в txt варианте
	 * @return bool
	 */
	public static function sendMail($from_name = NULL, $from_email = NULL, $to_name = NULL, $to_mail = NULL, $subject = NULL, $body = NULL, $is_html = TRUE)
	{
		$Mail = new self();
		$Mail -> setFromUser($from_email,$from_name);
		$Mail -> addAddress($to_mail,$to_name);
		$Mail -> setSubject($subject);
		$Mail -> setBody(View::get('./skins/common/mail',array(
			'subject' => $subject,
			'body' => $body,
		)));
		
		return $Mail -> send($is_html);
	}
}