<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс Request
 */

class Request
{
	/**
	 * Возвращает содержимое системной переменной
	 *
	 * @param string $index индекс переменной
	 * @param string $type тип переменной
	 * @param string $default значение по умолчанию, если индекс не найден или пуст
	 * @param array $var системная переменная
	 * @return mixed
	 */
	public static function getVar($index=null,$type=null,$default=null,&$var=null)
	{
		if(isset($var[$index]))
		{
			if(is_array($type))
			{
				foreach ($type as $func)
				{
					$var[$index] = Request::_toType($var[$index],$func);
				}
				return $var[$index];
			}
			else if($type)
			{
				return Request::_toType($var[$index],$type);
			}
			return Request::_toType($var[$index]);
		}
		return $default;
	}
	
	/**
	 * Возвращает содержимое системной переменной
	 *
	 * @param string $index индекс переменной
	 * @param string $value значение
	 * @param bool $is_rewrite перезаписывать значение переменно если оно есть или нет
	 * @param unknown_type $var системная переменная
	 */
	public static function setVar($index=null,$value=null,$is_rewrite=true,&$var=null)
	{
		if($is_rewrite)
		{
			$var[$index] = $value;
		}
		else
		{
			if(!isset($_GET[$index]))
			{
				$var[$index] = $value;
			}
		}
	}
	
	/**
	 * Возвращает содержимое системной переменной $_GET
	 *
	 * @param string $index индекс переменной
	 * @param string $type тип переменной
	 * @param string $default значение по умолчанию, если индекс не найден или пуст
	 * @return mixed
	 */
	public static function getGet($index=null,$type="string",$default=null)
	{
		return Request::getVar($index,$type,$default,$_GET);
	}

	/**
	 * Устанавливает содержимое системной переменной $_GET
	 *
	 * @param string $index индекс переменной
	 * @param string $value значение
	 * @param bool $is_rewrite перезаписывать значение переменно если оно есть или нет
	 */
	public static function setGet($index=null,$value=null,$is_rewrite=true)
	{
		Request::setVar($index,$value,$is_rewrite,$_GET);
	}
	
	/**
	 * Возвращает содержимое системной переменной $_POST
	 *
	 * @param string $index индекс переменной
	 * @param string $type тип переменной
	 * @param string $default значение по умолчанию, если индекс не найден или пуст
	 * @return mixed
	 */
	public static function getPost($index=null,$type="string",$default=null)
	{
		return Request::getVar($index,$type,$default,$_POST);
	}

	/**
	 * Устанавливает содержимое системной переменной $_POST
	 *
	 * @param string $index индекс переменной
	 * @param string $value значение
	 * @param bool $is_rewrite перезаписывать значение переменно если оно есть или нет
	 */
	public static function setPost($index=null,$value=null,$is_rewrite=true)
	{
		Request::setVar($index,$value,$is_rewrite,$_POST);
	}
	
	/**
	 * Проверяем загружен файл или нет
	 *
	 * @param string $name
	 * @return bool
	 */
	public static function isFileUpload($name = NULL)
	{
		if(isset($_FILES[$name]))
		{
			if($_FILES[$name]['size'])
			{
				return TRUE;
			}
			return FALSE;
		}
		return FALSE;
	}
	
	/**
	 * Проверяет, были ли получены POST данные или нет
	 *
	 * @return bool
	 */
	public static function isPost()
	{
		 return $_SERVER['REQUEST_METHOD'] == "POST";
	}
	
	/**
	 * Возвращает расширение загружаемого файла
	 *
	 * @param string $name имя файла
	 * @return string
	 */
	public static function getExtensionFileUpload($name = NULL)
	{
		if(Request::isFileUpload($name) == true)
		{
			$name_ar = explode('.', $_FILES[$name]['name']);
			return end($name_ar);
		}
		return FALSE;
	}
	
	/**
	 * Возвращает содержимое системной переменной $_REQUEST
	 *
	 * @param string $index индекс переменной
	 * @param string $type тип переменной
	 * @param string $default значение по умолчанию, если индекс не найден или пуст
	 * @return mixed
	 */
	public static function getRequest($index=null,$type="string",$default=null)
	{
		return Request::getVar($index,$type,$default,$_REQUEST);
	}
	
	/**
	 * Возвращает $_POST массив
	 *
	 * @return array
	 */
	public static function post()
	{
		return (array)$_POST;
	}
	
	/**
	 * Возвращает $_GET массив
	 *
	 * @return array
	 */
	public static function get()
	{
		return (array)$_GET;
	}
	
	/**
	 * Приводит переменную к нужному типу string|int|float|double|default
	 *
	 * @param mixed $var переменная 
	 * @param string $type тип переменной
	 * @return mixed
	 */
	private static function _toType($var=null,$type="string")
	{
		switch($type)
		{
			case"string":
				return (string)$var;
			break;
			case"bool":
				return (bool)$var;
			break;
			case"array":
				return (array)$var;
			break;
			case"int":
				return (int)$var;
			break;
			case"float":
			case"double":
				return (double)$var;
			break;
			default:
			case"default":
				if($type)
				{
					return call_user_func($type,$var);
				}
				return $var;
			break;
		}
	}
}