<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс системный, содержит часто используемые методы
 */

class Site
{
	/**
	 * Массив переменных скина
	 *
	 * @var array
	 */
	private static $var_ar = array();
	
	/**
	 * Авторматически подключает классы
	 *
	 */
	public static function registerAutoload($class_name=null)
	{
		function __autoload($class_name)
		{
			$file_name = strtolower(str_replace('_','/',$class_name)). ".php";

			if(!@include_once($file_name))
			{
				throw new Exception(Lng::_('Library not found'));
			}
		}
	}
	
	/**
	 * Возвращает базоввый index или admin
	 *
	 * @return string
	 */
	public static function getBaseFile()
	{
		static $file;
		
		if(!$file)
		{
			preg_match("/\/(index|admin).php/",$_SERVER['PHP_SELF'],$a);
			
			$file = $a[1];
		}
		
		return $file;
	}
	
	/**
	 * Возвращает текущий модуль
	 *
	 * @return string|bool
	 */
	public static function getCurrentModule()
	{
		return isset($_GET['mod']) ? $_GET['mod'] : FALSE;
	}
	
	//===========================================================
	
	/**
	 * Устанавливает значение переменной скина
	 *
	 * @param string $index имя переменной скина
	 * @param string $value содержимое переменной скина
	 */
	public static function setSkinVar($index = NULL, $value = NULL)
	{
		@self::$var_ar[((string)$index)] = (string)$value;
	}
	
	/**
	 * Добавляет значение переменной скина
	 *
	 * @param string $index имя переменной скина
	 * @param string $value содержимое переменной скина
	 */
	public static function addSkinVar($index = NULL, $value = NULL)
	{
		@self::$var_ar[((string)$index)] .= (string)$value;
	}
	
	/**
	 * Возвращает массив переменных скина
	 *
	 * @return array
	 */
	public static function getSkinVars()
	{
		return self::$var_ar;
	}
	
	/**
	 * Возвращает содержимое переменной скина по имени переменной
	 *
	 * @param string $index
	 * @return string
	 */
	public static function getSkinVar($index = NULL)
	{
		if(isset(self::$var_ar[$index]))
		{
			return self::$var_ar[$index];
		}
		return FALSE;
	}
	
	//===========================================================
	
	/**
	 * Возвращает сообщение об ошибке
	 *
 	 * @param string $view содержимое ошибки
	 * @param array $params_ar массив параметров передаваемых в вид
	 */
	public static function getPage($view = NULL, $params_ar = array())
	{
		return View::get('./skins/common/'.$view, $params_ar);
	}
	
	/**
	 * Возвращает сообщение
	 *
	 * @param string $message сообщение
	 * @param string $style тип сообщения true|0 - хорошее, false|1 - плохое 
	 * @return string
	 */
	public static function getMessage($message = NULL, $style = 0)
	{
		switch($style)
		{
			case"TRUE":
			case"0":
				$style = 'correct';
			break;
			case"FALSE":
			case"1":
				$style = 'wrong';
			break;
			default:
				$style = '';
			break;
		}

		return View::get('./skins/common/message',array(
			'style' 	=> $style,
			'message' 	=> $message,
		));
	}
	
	//===========================================================
	
	/**
	 * Оболочка для функции set_time_limit
	 *
	 * @param int $time время выполнения скрипта
	 */
	public static function setTimeLimit($time = 0)
	{
		if(function_exists('set_time_limit'))
		{
			set_time_limit($time);
		}
	}
	
	/**
	 * Оболочка для функции iconv
	 *
	 * @param string $in входная кодировка
	 * @param string $out "выходная" кодировка
	 * @param string $str текст
	 * @param string $def значение по умолчанию
	 * @return string
	 */
	public static function iconv($in = NULL, $out = NULL, $str = NULL, $def = NULL)
	{
		if(function_exists('iconv'))
		{
			return iconv($in,$out,$str);
		}
		return $def;
	}
	
	//===========================================================
	
	/**
	 * Возвращает хост сайта
	 *
	 * @return string
	 */
	public static function skin()
	{
		static $skin;
		
		if($skin == FALSE)
		{
			$skin = (string) Registry::get('Config') -> site -> skin;
		}
		return $skin;
	}
	
	//===========================================================
	
	/**
	 * Отображает отладочную информацию
	 *
	 */
	public static function showDebug()
	{
		$DB = Registry::get('DB');
		
		$separate = "<div style=\"border-top:1px solid Silver; margin-top: 10px\"></div>";
		
		$c  = "<div style='border: 1px solid #D90000; background: #FFE4B5; padding: 5px; font: 8pt Arial,Helvetica,sans-serif;'>";
		$c .= "<div align=\"center\"><b>Запросы к БД (".$DB -> getCountQuery()." шт.):</b></div><div align=\"left\">".join(";<br>",$DB -> getQueryHistory()).";";
		$c .= $separate;
		$c .= "<div align=\"center\"><b>Использовано памяти:</b></div>";
		$c .= "Скриптом: <u>".number_format((memory_get_usage()/(1024*1024)),5)." МБ</u><br>";
		$c .= "Скриптом и менеджером памяти PHP: <u>".number_format((memory_get_usage(true)/(1024*1024)),5)." МБ</u><br>";
		$c .= "</div>";
		$c .= $separate;
		
		if(isset($_SESSION))
		{
			$c .= "<div>";
			$c .= "<div align=\"center\"><b>Данные сессии:</b></div>";
			ob_start();
			echo"<pre>";print_r($_SESSION);echo"</pre>";
			$c .= ob_get_contents();
			ob_end_clean();
			$c .= "</div>";
		}
		if(defined('START_MB') == TRUE)
		{
			$c .= "<br><div align=\"center\"><i>Время генерации страницы - <b>".(microtime()-START_MB)."</b> мсек.</i></div>";
		}
		return $c .= "</div>";
	}
}