<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс работы со строками
 */

class Str
{ 
	//Периоды
	const DATE_YEAR   = 31556926;
	const DATE_MONTH  = 2629744;
	const DATE_WEEK   = 604800;
	const DATE_DAY    = 86400;
	const DATE_HOUR   = 3600;
	const DATE_MINUTE = 60;
	
	//Форматы дат
	const dateD 	= 'd.m.Y';
	const dateT 	= 'H:i';
	const dateDT 	= 'd.m.Y H:i';
	const dateDTS 	= 'd.m.Y H:i:s';
	
	/**
	 * Обрезает строку
	 *
	 * @param string $str строка 
	 * @param int $from начальная позиция
	 * @param int $len конечная позиция
	 * @return string
	 */
	public static function substr($str,$from,$len)
	{
		# utf8 substr
		# www.yeap.lv
	  return preg_replace('#^(?:[\x00-\x7F]|[\xC0-\xFF][\x80-\xBF]+){0,'.$from.'}'.
						   '((?:[\x00-\x7F]|[\xC0-\xFF][\x80-\xBF]+){0,'.$len.'}).*#s',
						   '$1',$str);
	}
	
	/**
	 * Определяем длину строки
	 *
	 * @param string $str строка
	 */
	public static function strlen($str)
	{
		if(function_exists('mb_strlen'))
		{
			return mb_strlen($str);
		}

		return strlen(utf8_decode($str));
	}
	
	/**
	 * Генерирует случайное слово
	 *
	 * @param string длина слова
	 * @param string [string,int,symbol] указываем с чего будет состоять слово
	 * @return string
	 */
	public static function randomText()
	{
		//Получаем аргументы
		$args_ar = func_get_args();
		$new_arr = array();
		
		//Определяем длину текста
		$length = $args_ar[0];
		unset($args_ar[0]);
		
		if(!sizeof($args_ar))
		{
			$args_ar = array("string","int","symbol");
		}
		
		$arr['string'] = array(
			 'a','b','c','d','e','f',
			 'g','h','i','j','k','l',
			 'm','n','o','p','r','s',
			 't','u','v','x','y','z',
			 'A','B','C','D','E','F',
			 'G','H','I','J','K','L',
			 'M','N','O','P','R','S',
			 'T','U','V','X','Y','Z');
		
		$arr['int'] = array(
			 '1','2','3','4','5','6',
			 '7','8','9','0');
		
		$arr['symbol'] = array(
			 '.','$','[',']','!','@',
			 '*', '+','-','{','}');
		
		//Создаем массив из всех массивов
		foreach($args_ar as $type)
		{
			if(isset($arr[$type]))
			{
				$new_arr = array_merge($new_arr,$arr[$type]);
			}
		}
		
		// Генерируем пароль
		$str = "";
		for($i = 0; $i < $length; $i++)
		{
			// Вычисляем случайный индекс массива
			$index = rand(0, count($new_arr) - 1);
			$str .= $new_arr[$index];
		}
		return $str;
	}
	
	/**
	 * Устанавливает префикс "http://" если тот небыл создан пользователем 
	 *
	 * @param string $url
	 * @return string
	 */
	public static function http($url=null)
	{
		$url = trim($url);
		if(strstr($url,"http://") || strstr($url,"https://"))
		{
			return $url;
		}
		return "http://".$url;
	}
	
//		<dateD>d.m.Y</dateD>
//		<dateDT>d.m.Y H:i</dateDT>
//		<dateDTS>d.m.Y H:i:s</dateDTS>
	
	/**
	 * Возвращает дату (d.m.Y)
	 *
	 * @param int $timestamp дата в формате timestamp
	 * @return string
	 */
	public static function dateD($timestamp = FALSE)
	{
		if($timestamp)
		{
			return date(self::dateD,$timestamp);
		}
		return date(self::dateD);
	}
	
	/**
	 * Возвращает дату и время (d.m.Y H:i)
	 *
	 * @param int $timestamp дата в формате timestamp
	 * @return string
	 */
	public static function dateDT($timestamp = FALSE)
	{
		if($timestamp)
		{
			return date(self::dateDT,$timestamp);
		}
		return date(self::dateDT);
	}
	
	/**
	 * Возвращает дату и время (H:i)
	 *
	 * @param int $timestamp дата в формате timestamp
	 * @return string
	 */
	public static function dateT($timestamp = FALSE)
	{
		if($timestamp)
		{
			return date(self::dateT,$timestamp);
		}
		return date(self::dateT);
	}
	
	/**
	 * Возвращает дату и время с секундами (d.m.Y H:i:s)
	 *
	 * @param int $timestamp дата в формате timestamp
	 * @return string
	 */
	public static function dateDTS($timestamp = FALSE)
	{
		if($timestamp)
		{
			return date(self::dateDTS,$timestamp);
		}
		return date(self::dateDTS);
	}
	
	/**
	 * Конвертирует дату типа дд.мм.гггг в формат timestamp
	 *
	 * @param int $date
	 * @param char $separate разделитель, по умолчанию "." точка
	 * @param int $H часы, если нужно
	 * @param int $i минуты, если нужно
	 * @param int $s секунды, если нужно
	 * @return int
	 */
	public static function convertDateToTimestamp($date = NULL, $separate = '.', $H = NULL, $i = NULL, $s = NULL)
	{
		$date_ar = array_map("intval",explode($separate,$date));
		$H = is_null($H) ? date("H") : $H;
		$i = is_null($i) ? date("i") : $i;
		$s = is_null($s) ? date("s") : $s;
		
		return mktime($H,$i,$s,$date_ar[1],$date_ar[0],$date_ar[2]);
	}

	/**
	 * Транслирует символы с русских на английские
	 *
	 * @param string $text
	 */
	public static function transRuToEn($text)
	{
 return strtr($text,array(

			"а" => "a",	"б" => "b",	"в" => "v",	"г" => "g",	"д" => "d",	"е" => "e",	"ё" => "yo",
			"ж" => "zh","з" => "z",	"и" => "i",	"й" => "y",	"к" => "k",	"л" => "l",	"м" => "m",
			"н" => "n",	"о" => "o",	"п" => "p",	"р" => "r",	"с" => "s",	"т" => "t",	"у" => "u",
			"ф" => "f",	"х" => "h",	"ц" => "ts","ч" => "ch","ш" => "sh","щ" => "shc","ъ" => "",
			"ы" => "y",	"ь" => "",	"э" => "e",	"ю" => "yu","я" => "ya",
			"А" => "A",	"Б" => "B",	"В" => "V",	"Г" => "G",	"Д" => "D",	"Е" => "E",	"Ё" => "Yo",
			"Ж" => "Zh","З" => "Z",	"И" => "I",	"Й" => "Y",	"К" => "K",	"Л" => "L",	"М" => "M",
			"Н" => "N",	"О" => "O",	"П" => "P",	"Р" => "R",	"С" => "S",	"Т" => "T",	"У" => "U",
			"Ф" => "F",	"Х" => "H",	"Ц" => "Ts","Ч" => "Ch","Ш" => "Sh","Щ" => "Shc","Э" => "E",
			"Ю" => "Yu","Я" => "Ya",
		));



	}
	
	
	/**
	 * Выполняет трансляцию некторых символов для корректного вывода ленты
	 *
	 * @param string $text
	 * @return string
	 */
	public static function transToUNICODE($text)
	 {
	    return strtr($text,array(
			"<" => "&lt;", 
	    	">" => "&gt;",
	    	'"' => "&quot;",
	    	"&" => "&amp;"
		));



	 }
	 
	 /**
	  * Конвертирует массив в строку атрибутов для тега
	  *
	  * @param array $attributes_ar
	  * @return string
	  */
	 public static function arrayToAtribute($attributes_ar=array())
	 {
		if(is_string($attributes_ar))
		{
			return $attributes_ar != "" ? " ".$attributes_ar : "";
		}

		$att = "";
		foreach($attributes_ar as $key => $val)
		{
			$att .= " ".$key."=\"".$val."\"";
		}

		return $att;
	 }
	 
	/**
	 * Выполняет транслитерацию
	 *
	 * @param string $str
	 */
	public static function transStr($str = NULL)
	{
		return preg_replace("/-{2,}/", "-",preg_replace("/[^a-z0-9]/i", "-", Str::transRuToEn($str)));
	}
	
	/**
	 * Get extended entry info (<!--more-->).
	 *
	 * There should not be any space after the second dash and before the word
	 * 'more'. There can be text or space(s) after the word 'more', but won't be
	 * referenced.
	 *
	 * The returned array has 'main' and 'extended' keys. Main has the text before
	 * the <code><!--more--></code>. The 'extended' key has the content after the
	 * <code><!--more--></code> comment.
	 *
	 * @since 1.0.0
	 *
	 * @param string $post Post content.
	 * @return array Post before ('main') and after ('extended').
	 */
	public static function getPagebreakAr($post, $chars = 0) 
	{
		if($chars > 0)
		{
			if(Str::strlen($post) > $chars)
			{
				return array('main' => Str::substr($post, 0, $chars).'...', 'extended' => $post);
			}
			return array('main' => $post, 'extended' => $post);
		}
		//Match the new style more links
		if ( preg_match('/<!-- pagebreak(.*?)?-->/', $post, $matches) ){
			list($main, $extended) = explode($matches[0], $post, 2);
		} else {
			$main = $post;
			$extended = '';
		}
	
		// Strip leading and trailing whitespace
		$main = preg_replace('/^[\s]*(.*)[\s]*$/', '\\1', $main);
		$extended = preg_replace('/^[\s]*(.*)[\s]*$/', '\\1', $extended);
	
		return array('main' => $main, 'extended' => $extended);
	}
	
	/**
	 * Возвращает кодировку текста
	 *
	 * @param string $path текст или путь к файлу, кодировку которого нужно определить
	 * @return string
	 */
	public static function textEncoding($path = NULL)
	{
		$charsets =  array ( 'w' => 0, 'k' => 0, 'i' => 0, 'm' => 0, 'a' => 0, 'c' => 0, 'u' => 0 );
		if(is_file($path))
		{
			$fp =  fopen ($path, "rb");
			$content =  fread ($fp , '1024');
			fclose ($fp);
		}
		else
		{
			$content = substr($path, 0, 1024);
		}
		
		     // Windows-1251
		$search_l_w = "~([\270])|([\340-\347])|([\350-\357])|([\360-\367])|([\370-\377])~s";
		$search_U_w = "~([\250])|([\300-\307])|([\310-\317])|([\320-\327])|([\330-\337])~s";
		
		     // Koi8-r
		$search_l_k = "~([\243])|([\300-\307])|([\310-\317])|([\320-\327])|([\330-\337])~s";
		$search_U_k = "~([\263])|([\340-\347])|([\350-\357])|([\360-\367])|([\370-\377])~s";
		
		     // Iso-8859-5
		$search_l_i = "~([\361])|([\320-\327])|([\330-\337])|([\340-\347])|([\350-\357])~s";
		$search_U_i = "~([\241])|([\260-\267])|([\270-\277])|([\300-\307])|([\310-\317])~s";
		
		     // X-mac-cyrillic
		$search_l_m = "~([\336])|([\340-\347])|([\350-\357])|([\360-\367])|([\370-\370])|([\337])~s";
		$search_U_m = "~([\335])|([\200-\207])|([\210-\217])|([\220-\227])|([\230-\237])~s";
		
		     // Ibm866
		$search_l_a = "~([\361])|([\240-\247])|([\250-\257])|([\340-\347])|([\350-\357])~s";
		$search_U_a = "~([\360])|([\200-\207])|([\210-\217])|([\220-\227])|([\230-\237])~s";
		
		     // Ibm855
		$search_l_c = "~([\204])|([\234])|([\236])|([\240])|([\242])|([\244])|([\246])|([\250])|".
		 "([\252])|([\254])|([\265])|([\267])|([\275])|([\306])|([\320])|([\322])|".
		 "([\324])|([\326])|([\330])|([\340])|([\341])|([\343])|([\345])|([\347])|".
		 "([\351])|([\353])|([\355])|([\361])|([\363])|([\365])|([\367])|([\371])|([\373])~s";
		$search_U_c = "~([\205])|([\235])|([\237])|([\241])|([\243])|([\245])|([\247])|([\251])|".
		 "([\253])|([\255])|([\266])|([\270])|([\276])|([\307])|([\321])|([\323])|".
		 "([\325])|([\327])|([\335])|([\336])|([\342])|([\344])|([\346])|([\350])|".
		 "([\352])|([\354])|([\356])|([\362])|([\364])|([\366])|([\370])|([\372])|([\374])~s";
		
		     // Utf-8
		$search_l_u = "~([\xD1\x91])|([\xD1\x80-\x8F])|([\xD0\xB0-\xBF])~s";
		$search_U_u = "~([\xD0\x81])|([\xD0\x90-\x9F])|([\xD0\xA0-\xAF])~s";
		
		 if ( preg_match_all ($search_l_w, $content, $arr, PREG_PATTERN_ORDER)) { $charsets['w'] +=  count ($arr[0]) * 3; }
		 if ( preg_match_all ($search_U_w, $content, $arr, PREG_PATTERN_ORDER)){ $charsets['w'] +=  count ($arr[0]); }
		
		 if ( preg_match_all ($search_l_k, $content, $arr, PREG_PATTERN_ORDER)) { $charsets['k'] +=  count ($arr[0]) * 3; }
		 if ( preg_match_all ($search_U_k, $content, $arr, PREG_PATTERN_ORDER)){ $charsets['k'] +=  count ($arr[0]); }
		
		 if ( preg_match_all ($search_l_i, $content, $arr, PREG_PATTERN_ORDER)) { $charsets['i'] +=  count ($arr[0]) * 3; }
		 if ( preg_match_all ($search_U_i, $content, $arr, PREG_PATTERN_ORDER)){ $charsets['i'] +=  count ($arr[0]); }
		
		 if ( preg_match_all ($search_l_m, $content, $arr, PREG_PATTERN_ORDER)) { $charsets['m'] +=  count ($arr[0]) * 3; }
		 if ( preg_match_all ($search_U_m, $content, $arr, PREG_PATTERN_ORDER)){ $charsets['m'] +=  count ($arr[0]); }
		
		 if ( preg_match_all ($search_l_a, $content, $arr, PREG_PATTERN_ORDER)) { $charsets['a'] +=  count ($arr[0]) * 3; }
		 if ( preg_match_all ($search_U_a, $content, $arr, PREG_PATTERN_ORDER)){ $charsets['a'] +=  count ($arr[0]); }
		
		 if ( preg_match_all ($search_l_c, $content, $arr, PREG_PATTERN_ORDER)) { $charsets['c'] +=  count ($arr[0]) * 3; }
		 if ( preg_match_all ($search_U_c, $content, $arr, PREG_PATTERN_ORDER)){ $charsets['c'] +=  count ($arr[0]); }
		
		 if ( preg_match_all ($search_l_u, $content, $arr, PREG_PATTERN_ORDER)) { $charsets['u'] +=  count ($arr[0]) * 3; }
		 if ( preg_match_all ($search_U_u, $content, $arr, PREG_PATTERN_ORDER)){ $charsets['u'] +=  count ($arr[0]); }
		
		 arsort ($charsets);
		$key = key($charsets);
		 if (  max ($charsets)==0 ){ return 'UTF-8'; }
		 elseif ( $key == 'w' ){ return 'cp1251'; }
		 elseif ( $key == 'k' ){ return 'KOI8-R'; } 
		 elseif ( $key == 'i' ){ return 'ISO-8859-5'; } 
		 elseif ( $key == 'm' ){ return 'X-MAC-CYRILLIC'; } 
		 elseif ( $key == 'a' ){ return 'IBM866';} 
		 elseif ( $key == 'c' ){ return 'IBM855';} 
		 elseif ( $key == 'u' ){ return 'UTF-8'; } 
	}
}