<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Файл содержит класс отвечающий за загрузку данных на сервер
 */

/**
 * Класс проверки загружаемого файла и копирования его в нужную директорию на сервере
 *
 */
class UploadFile
{
	/**
	 * Префикс для загружаемого файла
	 *
	 * @var string
	 */
	private $pref = "";
	/**
	 * Массив расширений файлов которые разрешено загружать
	 *
	 * @var array
	 */
	private $extensions = array();
	/**
	 * Массив размера файла в байта (минимальный, максимальный) который будет допускаться 
	 *
	 * @var array
	 */
	private $kb = array(0,0);
	/**
	 * Массив разрешения изображения
	 *
	 * @var array
	 */
	private $px = array(0,0);
	/**
	 * Путь к директории где будет сохранен файл
	 *
	 * @var string
	 */
	private $path;
	/**
	 * Содержит расширение загружаемого файла
	 *
	 * @var string
	 */
	private $extension;
	/**
	 * Содержит имя файла
	 *
	 * @var string
	 */
	private $name;
	/**
	 * Загруженный файл
	 *
	 * @var array
	 */
	private $userfile;

	/**
	 * Режим валидации файла или загрузки (true - режим валидации, false - режим загрузки)
	 *
	 * @var bool
	 */
	private $is_validate = false;
	
	/**
	 * Проверяет загрузился файл на сервер или нет
	 *
	 * @param string $userfile имя загружаемого файла
	 */
	public function __construct($userfile)
	{
		$this -> userfile = $userfile;
		if(isset($this -> userfile['error']) && $this -> userfile['error'])
		{
			throw new Exception_Default(Lng::_('Не удалось загрузить файл')." <i>".$this -> userfile['name']."</i> ".Lng::_('полностью')."!");
		}
		else
		{
			$ext_ar = explode(".", $this -> userfile['name']);
			//Определяем расширение загружаемого файла
			$this -> extension = strtolower(end($ext_ar));
		}
	}

	/**
	 * Префикс добавляемый к имени загруженного файла
	 *
	 * @param string $pref
	 */
	public function setFilePref($pref="")
	{
		$this -> pref = (string)$pref;
	}

	/**
	 * Имя загруженного файла файла
	 *
	 * @param string $name
	 */
	public function setFileName($name=null)
	{
		$this -> name = (string)$name;
	}

	/**
	 * Массив расширений, которые разрешено загружать.
	 * Передать в качестве параметра через запятую.
	 */
	public function setFileExtensions($extensions=null)
	{
		if(!is_array($extensions))
		{
			$extensions = func_get_args();
		}
		foreach($extensions as $extension)
		{
			$this -> extensions[] = strtolower($extension);
		}
	}

	/**
	 * Допустимый размер на загружаемый файл в байтах (минимальный и максимальный допустимые размеры файла)
	 *
	 * @param int $min минимальный размер
	 * @param int $max максимальный размер
	 */
	public function setFileByte($min=0,$max=0)
	{
		$min = 1024 * (int)$min;
		$max = 1024 * (int)$max;
		$this -> kb = array($min,$max);
	}

	/**
	 * Допустимое разрешение на загружаемое изображение
	 *
	 * @param int $width ширина в px
	 * @param int $height высота в px
	 */
	public function setFilePx($width=0,$height=0)
	{
		$width = (int)$width;
		$height = (int)$height;
		$this -> px = array($width,$height);
	}

	/**
	 * Путь к директории куда будет загружаться файл
	 *
	 * @param string $path
	 */
	public function setFilePath($path=null)
	{
		$this -> path = (string)$path;
	}

	
	/**
	 * Возвращает имя загруженного файла
	 *
	 * @return string
	 */
	public function getFileName()
	{
		return $this -> name;
	}
	
	/**
	 * Выполняет загрузку файла
	 *
	 * @return array название файла или ошибка
	 */
	public function upload()
	{
		$this -> userfile['size'] = number_format(($this -> userfile['size']/1024),2,".","");
		$this -> kb[0] = number_format(($this -> kb[0]/1024),2,".","");
		$this -> kb[1] = number_format(($this -> kb[1]/1024),2,".","");
		
		if(!in_array($this -> extension,$this -> extensions))
		{
			throw new Exception_Default(Lng::_('Загружаемый файл')." <b>".$this -> userfile['name']."</b> ".Lng::_('имеет не правильное расширение')." - \"<b>".$this -> extension."</b>\",
				".Lng::_('разрешается загружать файлы с расширениями').": \"*.".implode("; *.",$this -> extensions).";\"");
		}
		else if($this -> userfile['size'] < $this -> kb[0])
		{
			throw new Exception_Default(Lng::_('Загружаемый файл')." <b>".$this -> userfile['name']."</b> (".$this -> userfile['size']." kb.) ".Lng::_('меньше на')." <b>\"".
				($this -> kb[0] - $this -> userfile['size'])." kb.\"</b> ".Lng::_('требуемого')." (".$this -> kb[0]." kb.).");
		}
		else if($this -> userfile['size'] > $this -> kb[1])
		{
			throw new Exception_Default(Lng::_('Загружаемый файл')." <b>".$this -> userfile['name']."</b> (".$this -> userfile['size']." kb.) ".Lng::_('больше на')." <b>\"".
				($this -> userfile['size'] - $this -> kb[1])." kb.\"</b> ".Lng::_('требуемого')." (".$this -> kb[1]." kb.).");
		}
		else
		{
			$this -> name = $this -> pref.$this -> name.$this -> extension;
			if(GetImageSize($this -> userfile['tmp_name']))
			{
				return $this -> checkFileImage();
			}
			else if($this -> is_validate == true)
			{
				return $this -> name;
			}
			else
			{
				return $this -> moveUploadedFile();
			}
		}
	}

	/**
	 * Проверяет соответствие изображения к загрузке
	 *
	 * @return array название файла или ошибка
	 */
	private function checkFileImage()
	{
		$size_px = GetImageSize($this -> userfile['tmp_name']);
		if($size_px[0] > $this -> px[0])
		{
			throw new Exception_Default(Lng::_('Разрешение файла')." <i>".$this -> userfile['name']."</i> ".Lng::_('превышает допустимые нормы, ширина загружаемого файла')." - 
				<b>\"".$size_px[0]."\"</b>, ".Lng::_('а требуется')." - <b>\"".$this -> px[0]."\"</b>");
		}
		else if($size_px[1] > $this -> px[1])
		{
			throw new Exception_Default(Lng::_('Разрешение файла')." <i>".$this -> userfile['name']."</i> ".Lng::_('превышает допустимые нормы, высота загружаемого файла')." - 
				<b>\"".$size_px[1]."\"</b>, ".Lng::_('а требуется')." - <b>\"".$this -> px[1]."\"</b>");
		}
		else if($this -> is_validate == true)
		{
			return $this -> name;
		}
		else
		{
			return $this -> moveUploadedFile();
		}
	}

	/**
	 * Выполняем валидацию данных файла
	 *
	 * @return string новое имя файла
	 */
	public function validate()
	{
		$this -> is_validate = true;
		return $this -> upload();
	}
	
	/**
	 * Сохраняет файл
	 *
	 * @return array ошибка
	 */
	private function moveUploadedFile()
	{
		if(!is_dir($this -> path))
		{
			throw new Exception_Default(Lng::_('Невозможно сохранить файл')."!");
		}
		if(move_uploaded_file($this -> userfile['tmp_name'], ($this -> path.$this -> name)))
		{
			return $this -> name;
		}
		else
		{
			throw new Exception_Default(Lng::_('Не удалось сохранить файл')."!");
		}
	}

	/**
	 * Переформировывает массив загруженных файлов
	 *
	 * @param array $files
	 * @return array
	 */
	public static function prepareArrayFiles($files=array())
	{
		$files_ar = array();
		
		foreach($files['name'] as $index => $name)
		{
			$files_ar[$index]['name'] 		= $name;
			$files_ar[$index]['type'] 		= $files['type'][$index];
			$files_ar[$index]['tmp_name'] 	= $files['tmp_name'][$index];
			$files_ar[$index]['error'] 		= $files['error'][$index];
			$files_ar[$index]['size'] 		= $files['size'][$index];
		}
		return $files_ar;
	}
	
	
	/**
	 * Save an uploaded file to a new location. If no filename is provided,
	 * the original filename will be used, with a unique prefix added.
	 * Method from Kohana Framework
	 *
	 * @param   array    uploaded file data
	 * @param   string   new filename
	 * @param   string   new directory
	 * @param   integer  chmod mask
	 * @return  string   on success, full path to new file
	 * @return  FALSE    on failure
	 */
	public static function save(array $file, $filename = NULL, $directory = NULL, $chmod = 0644)
	{
		if ( ! isset($file['tmp_name']) OR ! is_uploaded_file($file['tmp_name']))
		{
			// Ignore corrupted uploads
			return FALSE;
		}

		if ($filename === NULL)
		{
			// Use the default filename, with a timestamp pre-pended
			$filename = uniqid().$file['name'];
		}

		if ($directory === NULL)
		{
			// Use the pre-configured upload directory
			$directory = Upload::$default_directory;
		}

		if ( ! is_dir($directory) OR ! is_writable(realpath($directory)))
		{
			throw new Exception_Default('Directory '.$directory.' must be writable');
		}

		// Make the filename into a complete path
		$filename = $directory.$filename;

		if (move_uploaded_file($file['tmp_name'], $filename))
		{
			if ($chmod !== FALSE)
			{
				// Set permissions on filename
				chmod($filename, $chmod);
			}

			// Return new file path
			return $filename;
		}

		return FALSE;
	}

	//===========================================================
	
	//СТРОГО ЗАПРЕЩЕНО: создавать мим-типы файлов - php, phtml, xml и tpl. В противном случае можно будет скачать файл и посмотреть его содержимое,
	//в случае с php (и остальными файлами) это крайне опасно
	private static	$content_type_ar = array(
		"zip" => "application/x-zip-compressed",
		"rar" => "application/x-rar-compressed",
		"gz" => "encoding/x-gzip",
		"exe" => "application/octet-stream",
		"bin" => "application/octet-stream",
		"iso" => "application/octet-stream",
		"z" => "encoding/x-compress",
		"gz" => "encoding/x-gzip",
		"tar" => "application/x-tar",
		"gtar" => "application/x-gtar",
		"pdf" => "application/pdf",
		"wav" => "audio/x-wav",
		"mp3" => "audio/x-mpeg",
		"mp2" => "audio/x-mpeg",
		"midi" => "audio/midi",
		"mid" => "audio/midi",
		"ra" => "audio/x-pn-realaudio",
		"ram" => "audio/x-pn-realaudio",
		"qt" => "video/quicktime",
		"mov" => "video/quicktime",
		"avi" => "video/x-msvideo",
		"mpg" => "video/mpeg",
		"mpeg" => "video/mpeg",
		"mpe" => "video/mpeg",
		"asf" => "video/x-ms-asf",
		"png" => "image/png",
		"gif" => "image/gif",
		"jpg" => "image/jpeg",
		"jpeg" => "image/jpeg",
		"jpe" => "image/jpeg",
		"bmp" => "image/x-ms-bmp",
		"tcl" => "application/x-tcl",
		"html" => "text/html",
		"htm" => "text/html",
		"shtml" => "magnus-internal/parsed-html",
		"txt" => "text/plain",
		"cgi" => "magnus-internal/cgi",
		"pl" => "application/x-perl",
		"perl" => "application/x-perl",
		"hlp" => "application/mshelp",
		"doc" => "application/msword",
		"docx" => "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
		"xls" => "application/vnd.ms-excel",
		"xlsx" => "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
		"rtf" => "application/msword",
		"js" => "application/x-javascript",
		"sh" => "application/x-sh",
		"csh" => "application/x-csh",
		"csv" => "application/csv",
	
		"xml" => "text/xml",
	);
	
	/**
	 * Выполняет загрузку файла
	 *
	 * @param string $path путь к файлу
	 */
	public static function loadFile($path = NULL)
	{
		if(!$path || !is_file($path))
		{
			die("Загружаемый файл отсутствует");
		}

		$file_size = filesize($path);
		$file_name = basename($path);
		$file_name_ar = explode(".",$file_name);
		$file_ext = end($file_name_ar);
		$mtype = isset(self::$content_type_ar[$file_ext]) ? self::$content_type_ar[$file_ext] : "text/plain";
		ob_start();
		ob_clean();
	
@		header('Expires: 0');
@		header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
@		header("Content-Type: ".$mtype);
@		header("Accept-Ranges: bytes");
@		header("Content-Disposition: filename=".$file_name.";" );
@		header("Content-transfer-encoding: binary");
@		header("Content-Length: $file_size");
		echo file_get_contents($path);
		exit;
	}
	
	/**
	 * Выдает содержимое сонтента на загрузку как файл
	 *
	 * @param string $content содержимое
	 * @param string $file_name название файла
	 */
	public static function loadContentAsFile($content = NULL, $file_name = NULL)
	{
		$file_size = Str::strlen($content);
		$file_name_ar = explode(".",$file_name);
		$file_ext = end($file_name_ar);
		$mtype = isset(self::$content_type_ar[$file_ext]) ? self::$content_type_ar[$file_ext] : "text/plain";
		ob_start();
		ob_clean();
	
@		header('Expires: 0');
@		header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
@		header("Content-Type: ".$mtype);
@		header("Accept-Ranges: bytes");
@		header("Content-Disposition: filename=".$file_name.";" );
@		header("Content-transfer-encoding: binary");
@		header("Content-Length: $file_size");
		echo $content;
		exit;
	}
}