<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Класс работы с данными пользователя
 */

class User
{
	/**
	 * Уровни доступа к сайту
	 *
	 */
	const ROLE_ADMIN 	= 'administrator';
    const ROLE_USER 	= 'user';
    const ROLE_GUEST 	= 'guest';
    const ROLE_BANNED 	= 'banned';
    const ROLE_DELETE 	= 'delete';
	
	/**
	 * Данные пользователя
	 *
	 * @var array
	 */
	private static $data_ar = array();
	
	/**
	 * Устанавливает данные пользователя
	 *
	 * @param mixed $index данные пользователя
	 * @param mixed $value данные пользователя
	 */
	public static function set($index = FALSE, $value = NULL)
	{
		User::createSession();
		if($value)
		{
			$_SESSION['mod_user']['us_'.$index] = $value;
		}
		else
		{
			$_SESSION['mod_user'] = (array)$index;
		}
	}
	
	/**
	 * Возвращает данные пользователя
	 *
	 * @param string $index
	 * @return string|int|bool
	 */
	public static function get($index = FALSE)
	{
		if(!$index)
		{
			return $_SESSION['mod_user'];
		}
		if(isset($_SESSION['mod_user']['us_'.$index]))
		{
			return $_SESSION['mod_user']['us_'.$index];
		}
		return FALSE;
	}
	
	/**
	 * Проверяет привилегию пользователя
	 *
	 * @param array $privilege массив привилегий
	 * @return bool
	 */
	public static function checkPrivilege($privilege = NULL)
	{
		$privilege = (string)$privilege;
		if(strstr(User::get('role'),$privilege))
		{
			return TRUE;
		}
		return FALSE;
	}
	
	/**
	 * Проверяет привилегии
	 *
	 * @param array $privileges_ar массив привилегий
	 * @return bool
	 */
	public static function checkPrivileges($privileges_ar = array())
	{
		if(sizeof($privileges_ar))
		{
			foreach($privileges_ar as $privilege)
			{
				if(strstr(User::get("role"),$privilege))
				{
					return true;
				}
			}
		}
		return false;
	}
	
	/**
	 * Проверяет доступ пользователя к виду, на основе его привилегий
	 *
	 * @param array $privileges_ar массив привилегий
	 * @param bool $is_exception
	 * @return  bool $access
	 */
	public static function checkPrivilegesPage($privileges_ar = array(), $is_exception = FALSE)
	{
		$access = User::checkPrivileges($privileges_ar);
		if($is_exception && !$access)
		{
			throw new Exception_Privileges();
		}

		return $access;
	}
	
	/**
	 * Создает сессию
	 *
	 */
	private static function createSession()
	{
		if(!isset($_SESSION['mod_user']) || !is_array($_SESSION['mod_user']))
		{
			$_SESSION['mod_user'] = array();
		}
	}
	
	/**
	 * Возвращает ip адрес пользователя учитывая прокси-сервер
	 *
	 * @return string
	 */
	public static function getIp()
	{
		if(getenv("HTTP_CLIENT_IP") && strcasecmp(getenv("HTTP_CLIENT_IP"),"unknown"))
		{
			$ip = getenv("HTTP_CLIENT_IP");
		}
		else if(getenv("HTTP_X_FORWARDED_FOR") && strcasecmp(getenv("HTTP_X_FORWARDED_FOR"), "unknown"))
		{
			$ip = getenv("HTTP_X_FORWARDED_FOR");
		}
		else if(getenv("REMOTE_ADDR") && strcasecmp(getenv("REMOTE_ADDR"), "unknown"))
		{
			$ip = getenv("REMOTE_ADDR");
		}
		else if(!empty($_SERVER['REMOTE_ADDR']) && strcasecmp($_SERVER['REMOTE_ADDR'], "unknown"))
		{
			$ip = $_SERVER['REMOTE_ADDR'];
		}
		else
		{
		    $ip = "unknown";
		}
  		return $ip;
	}
	
	/**
	 * Определяет операционную систему пользователя
	 * 
	 * @return string
	 */
	public static function getOS()
	{
		if(isset($_SERVER["HTTP_USER_AGENT"]) == true)
		{
			if(strstr($_SERVER["HTTP_USER_AGENT"], "Win"))
			{
				return "Windows";
			}
			else if(strstr($_SERVER["HTTP_USER_AGENT"], "Mac"))
			{
				return "Macintosh";
			}
			else if(strstr($_SERVER["HTTP_USER_AGENT"], "Lin"))
			{
				return "Linux";
			}
			else if(strstr($_SERVER["HTTP_USER_AGENT"], "Uni"))
			{
				return "Unix";
			}
			else if(strstr($_SERVER["HTTP_USER_AGENT"], "BSD"))
			{
				return "FreeBSD";
			}
			return "Other";	
		}
		return "Undefined";
	}
	
	/**
	 * Возвращает браузер пользователя
	 *
	 * @return string
	 */
	public static function getBrowser()
	{
		if(isset($_SERVER["HTTP_USER_AGENT"]) == true)
		{
			if(strstr($_SERVER["HTTP_USER_AGENT"], "Opera"))
			{
				return "Opera";
			}
			else if (strstr($_SERVER["HTTP_USER_AGENT"], "MSIE"))
			{
				return "MSIE";
			}
			elseif(strstr($_SERVER["HTTP_USER_AGENT"], "Chrome"))
			{
				return "Chrome";
			}
			elseif(strstr($_SERVER["HTTP_USER_AGENT"], "Safari"))
			{
				return "Safari";
			}
			elseif(strstr($_SERVER["HTTP_USER_AGENT"], "Mozilla"))
			{
				return "Mozilla";
			}
				elseif(strstr($_SERVER["HTTP_USER_AGENT"], "AOL"))
			{
				return "AOL";
			}
			return "Other";
		}
		return "Undefined";
	}
	
	/**
	 * Проверяет пользователь был авторизирован или нет
	 *
	 * @return bool
	 */
	public static function isAuth()
	{
		static $access;

		if($access == FALSE)
		{
			$access = self::isAdmin() || self::isUser();
		}
		return $access;		
	}
	
	/**
	 * Проверяет, является ли пользователь админом
	 *
	 * @return bool
	 */
	public static function isAdmin()
	{
		static $access;
		
		if($access == FALSE)
		{
			$access = self::get('role') == self::ROLE_ADMIN;
		}
		return $access;
	}
	
	/**
	 * Проверяет, является ли пользователь обычным пользователем
	 *
	 * @return bool
	 */
	public static function isUser()
	{
		static $access;
		
		if($access == FALSE)
		{
			$access = self::get('role') == self::ROLE_USER;
		}
		return $access;
	}
	
	/**
	 * Проверяет, является ли пользователь гостем
	 *
	 * @return bool
	 */
	public static function isGuest()
	{
		static $access;
		
		if($access == FALSE)
		{
			$access = self::get('role') == self::ROLE_GUEST;
		}
		return $access;
	}
	
	/**
	 * Проверяет, находится ли администратор в панели администратора
	 *
	 * @return bool
	 */
	public static function isCPanel()
	{
		static $access;

		if($access == FALSE)
		{
			$access = self::isComeAsAdmin() && self::isAdmin();
		}
		return $access;
	}
	
	/**
	 * Проверяет вошел пользователь через страничку admin.php или нет
	 *
	 * @return bool
	 */
	public static function isComeAsAdmin()
	{
		static $access;
		
		if($access == FALSE)
		{
			$access = 'admin' == Site::getBaseFile();
		}
		return $access;
	}
}