<?php defined("MOMENT_BOARD") or die("Access denied");

/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Контроллер "Доска объявлений", для гостя
 */
class Modules_Board_Controllers_Index extends Guard_Controller
{
    //===========================================================
    // КОНФИГУРАЦИЯ НАСТРОЕК ОБЪЯВЛЕНИЯ
    //===========================================================
    /**
     * Группа для доп. изображений объявлений
     *
     */
    const GROUP_IMG = 'board_ad';

    /**
     * Количество изображений которое разрешено загружать к объявлению
     *
     */
    const IMAGES_UPLOADED_COUNT = 8;

    /**
     * Максимальный размер для ресайза изображения
     *
     */
    const IMG_MAX_RESIZE = 760;

    /**
     * Минимальный размер для ресайза изображения
     *
     */
    const IMG_MIN_RESIZE = 90;

    /**
     * Группа для кэша
     *
     */
    const CATCH_GROUP = 'mod_board';

    /**
     * Путь к изображению ватермарка
     *
     */
    const PATH_TO_WATERMARK = './images/images/watermark.png';

    /**
     * Расширения изображений допустимых для загрузки
     *
     * @var unknown_type
     */
    public static $upload_extensions_ar = array('jpg', 'jpeg', 'png', 'gif');

    /**
     * Расширения изображений допустимых для загрузки (для вида)
     *
     */
    const UPLOAD_EXTENSIONS_VIEW = '*.jpg; *.jpeg; *.png; *.gif';

    /**
     * Масимально допустимый файл для загрузки в килобайтах
     *
     */
    const UPLOAD_MAX_SIZE = 5120;

    /**
     * Масимально допустимый файл для загрузки в мегабайтах (для вида)
     *
     */
    const UPLOAD_MAX_SIZE_VIEW = '5 мегабайт';

    /**
     * Каталоги для загрузки и просмотра фотографий
     *
     */
    const PATH_DIR_NORMAL = './files/upload/board/ad/';
    const PATH_VIEW_NORMAL = '/files/upload/board/ad/';
    const PATH_DIR_THUMB = './files/upload/board/ad/thumb/';
    const PATH_VIEW_THUMB = '/files/upload/board/ad/thumb/';


    //===========================================================
    // КОНФИГУРАЦИЯ НАСТРОЕК КАТЕГОИРИЙ
    //===========================================================

    /**
     * Расширения изображений допустимых для загрузки
     *
     * @var unknown_type
     */
    public static $upload_cat_extensions_ar = array('png');

    /**
     * Расширения изображений допустимых для загрузки (для вида)
     *
     */
    const UPLOAD_CAT_EXTENSIONS_VIEW = '*.png;';

    /**
     * Масимально допустимый файл для загрузки в килобайтах
     *
     */
    const UPLOAD_CAT_MAX_SIZE = 1024;

    /**
     * Масимально допустимый файл для загрузки в мегабайтах (для вида)
     *
     */
    const UPLOAD_CAT_MAX_SIZE_VIEW = '1 мб.';

    /**
     * Ресайза изображения для размер
     *
     */
    const IMG_CAT_RESIZE = 50;

    /**
     * Каталоги для загрузки и просмотра фотографий
     *
     */
    const PATH_CAT_DIR_NORMAL = './files/upload/board/category/';
    const PATH_CAT_VIEW_NORMAL = '/files/upload/board/category/';

    /**
     * Имя группы рейтинга для компонента рейтинга
     *
     * @var string
     */
    protected $com_group_rating = 'board_ad';

    /**
     * Количество объявлений на страницу
     *
     * @var int
     */
    private $ad_on_page = 20;

    /**
     * Отображает главную страницу сайта
     *
     */
    public function indexAction()
    {
        if (isset($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING'] == '/board.html') {
            URL::redirect('/');
        }
        //Вызываем подсказики
        Element_Tooltip::get(".mod-board-cat a");

        //Получаем настройки доски
        $Config = parent::getModel("Settings")->getConfig();

        //Получаем данные всех категорий
        $cat_ar = parent::getLib('Catch')->getCatAr();
        //Получаем количество объявлений в категориях
        $cat_ad_ar = parent::getLib('Catch')->getCountAdInCategory();

        $this->view->block_topin = '';
        if ($Config->terms->topin->isShowAd == '1') {
            //Получаем данные TOPIN объявлений
            $topin_ar = parent::getLib('Catch')->getTopinAdAr();
            $rand_keys = array();
            if (sizeof($topin_ar) > 0) {
                //Определяем количество объявлений
                $count_topin = intval($Config->terms->topin->count);
                $real_count_topin = sizeof($topin_ar);
                if ($real_count_topin < $count_topin) {
                    $count_topin = $real_count_topin;
                }
                $rand_keys = array_rand($topin_ar, $count_topin);
                $rand_keys = is_array($rand_keys) ? $rand_keys : array($rand_keys);
            }

            //Формируем блок с topin объявлениями
            $Phtml = parent::getTemplate('block.topin');
            $Phtml->ad_ar = $topin_ar;
            $Phtml->rand_keys = $rand_keys;
            $Phtml->rows = intval($Config->terms->topin->rows);
            $Phtml->columns = intval($Config->terms->topin->columns);
            $this->view->block_topin = $Phtml->getView();
        }

        //Подсчитываем объявления в родительских категориях
        parent::getLib()->getCountAdInCat($cat_ad_ar, 0, $calc_cat_ar);
        //Получаем часть дерева
        $cat_ar = Category::getTreeByDepth($cat_ar, 0, 3);

        $this->view->parent_cat_ar = array();
        if (isset($cat_ar[0])) {
            //Передаем данные в вид
            $this->view->parent_cat_ar = $cat_ar[0];
            unset($cat_ar[0]);
        }
        $this->view->cat_ar = $cat_ar;
        $this->view->cat_ars = array_chunk($this->view->parent_cat_ar, 3, TRUE);
        $this->view->calc_cat_ar = $calc_cat_ar;

        //Если нужно, отображаем последние объявления на главной странице
        $this->view->AdAr = array();
        if (intval($Config->general->isShowAdOnIndexPage) == 1) {
            $this->view->AdAr = parent::getModel("Ad")->getAdByLimitUnlock(0, 5);
        }

        //Вызываем статьи
        $this->view->ArticlesAr = parent::getModel("News", "News")->getListArticlesByLimit();
    }

    /**
     * Отображает содержимое категории
     *
     */
    public function catAction()
    {
        //Вызываем подсказики
        Element_Tooltip::get(".mod_board-cat_list a");

        //Первоначальная установка данных
        $cat_id = Request::getGet("cat_id", "int");

        //Получаем данные всех категорий и формируем с них дерево
        $cat_ar = parent::getLib('Catch')->getCatAr();
        //Получаем количество объявлений в категориях
        $cat_ad_ar = parent::getLib('Catch')->getCountAdInCategory();
        //Получаем данные текущей категории
        $Cat = parent::getModel('category')->getCategoryById($cat_id);

        //ПРОВЕРКА. В том случае, если пользователь самостоятельно, т.е. вручную вводит ссылки а их нет, выполняется следующий код
        if (isset($Cat->cat_id) == FALSE) {
            throw new Exception_440(Lng::_('Выбранная категория отсутствует'));
        }

        //Полчаем path way
        $this->view->path_way = parent::getLib()->getPathWay($cat_ar, $cat_id);

        //Подсчитываем объявления в родительских категориях
        parent::getLib()->getCountAdInCat($cat_ad_ar, 0, $calc_cat_ar);
        //Получаем часть дерева, для формирования подрубрик
        $cat_for_ad_ar = Category::getTreeByDepth($cat_ar, $cat_id, 1000);
        //Получаем часть дерева, для формирования подрубрик
        $cat_ar = Category::getTreeByDepth($cat_ar, $cat_id, 2);


        //Переформировываем массив категорий для получения по ним объявлений
        $cat_fad_ar = parent::getLib()->prepareCatData($cat_for_ad_ar);
        $cat_fad_ar[$cat_id] = $cat_id;

        //Определяем количество объявлений в категориях
        $count_ad = parent::getModel("category")->getCountAdInCategoryByCatAr($cat_fad_ar);

        //Определяем сколько подкатегорий выводить в колонке
        $count_subcat = 3;
        if (isset($cat_ar[$cat_id])) {
            $count_subcat = ceil(sizeof($cat_ar[$cat_id]) / 3);
            $this->view->cat_ars = array_chunk($cat_ar[$cat_id], $count_subcat, TRUE);
        }

        //Определяем номер текущей страницы
        $page = BreakPage::getPageNum();

        //View
        Site::setSkinVar("title", $Cat->cat_meta_title);
        Site::setSkinVar("keywords", $Cat->cat_meta_keywords);
        Site::setSkinVar("description", $Cat->cat_meta_description);
        Site::addSkinVar('canonical', URL::site('index.php?mod=board&go=cat&cat_id=' . $cat_id, $Cat->cat_title));

        $this->view->AdAr = parent::getModel("Ad")->getAdByCatArLimit($cat_fad_ar, (($page - 1) * $this->ad_on_page), $this->ad_on_page);
        $this->view->Cat = $Cat;
        $this->view->cat_ar = $cat_ar;
        $this->view->cat_id = $cat_id;
        $this->view->cat_title = $Cat->cat_title;
        $this->view->calc_cat_ar = $calc_cat_ar;
        $this->view->parent_count = isset($calc_cat_ar[$Cat->cat_parent_id][$cat_id]) ? $calc_cat_ar[$Cat->cat_parent_id][$cat_id] : 0;
        //Отображать или не отображать ссылку на форму размещения объявления
        $this->view->show_link_addad_form = !isset($cat_ar[$cat_id]) ? true : false;
        //Разбивка по странично
        $this->view->breakpage = BreakPage::getPages($count_ad, $this->ad_on_page, $page, "index.php?mod=board&go=cat&cat_id=" . $cat_id . "&page=", false);

        //К заголовку добавляем номер страницы
        BreakPage::addTitlePageNum();

    }

    /**
     * Добавляет объявление
     *
     */
    public function addAction()
    {
        //Установка данных
        $cat_id = Request::getGet("cat_id", "int", Request::getPost("cat_id", "int"));

        //Получаем данные настроек
        $Settings = parent::getModel("Settings")->getConfig();
        //Блокируем, если стоит проверка на подтверждение подачи объявления по Email
        if (intval($Settings->general->isAddAdWithoutRegistration) == 0) {
            parent::setView('./modules/board/views/index/add_lock.phtml');
            return TRUE;
        }

        if (Request::isPost()) {
            try {
                //По умолчанию определяем, что ошибок во время выполнения скрипта не возникало
                $is_error_foto = FALSE;
                //По умолчанию, пользователь был зарегистрирован ранее
                $is_registration = FALSE;
                //Пароль по умолчанию
                $password = '';
                //ID пользователя разместивщего объявление
                $us_id = 0;
                //По умолчанию, пароль введен верно
                $error_pass_code = FALSE;

                //Убираем лишние пробелы
                $_POST['ad_email'] = trim($_POST['ad_email']);

                //Установка пост данных формы, на тот случай если возникла ошибка
                $this->view->ad_name = $_POST['ad_name'];
                $this->view->ad_email = $_POST['ad_email'];
                $this->view->ad_phone = $_POST['ad_phone'];
                $this->view->ad_site = $_POST['ad_site'];
                $this->view->ad_title = $_POST['ad_title'];
                $this->view->ad_text = $_POST['ad_text'];
                $this->view->cat_id = (int)$_POST['cat_id'];
                $this->view->ad_keep = $_POST['ad_keep'];
                $this->view->ad_region_id = (int)$_POST['ad_region_id'];
                $this->view->ad_sum = floatval($_POST['ad_sum']);

                //Проверяем полученные данные
                parent::getLib()->checkAdData(parent::getModel("Category"), array(
                    'check_captcha' => TRUE
                ));

                //Выполняем валидацию загружаемым файлам
                $ad_fotos_ar = parent::getLib()->validateFotos();

                //Получаем данные пользователя по логину
                $UserData = parent::getModel("Users", "Users")->getUserByEmail($_POST['ad_email']);
                try {
                    //Если такой пользователь есть, значит нужно проверить его пароль
                    CheckData::existsDataObject($UserData);

                    //Теперь получаем данные пользователя по логину и паролю
                    $UserData = FALSE;
                    if (isset($_POST['password'])) {
                        $UserData = parent::getModel("Users", "Users")->getUserByEmailPassword($_POST['ad_email'], $_POST['password']);
                    }

                    try {
                        try {
                            //Если такой пользователь есть, значит от его имени можно разместить объявление
                            CheckData::existsDataObject($UserData);
                        } catch (Exception_CheckData $e) {
                            throw new Exception(Lng::_("FALSE:Не правильно введен пароль"));
                        }

                        //Если пользователь удален или заблокирован, запрещаем добавлять объявления
                        if ($UserData->us_role == User::ROLE_DELETE) {
                            throw new Exception(Lng::_("FALSE:Объявление добавить не возможно. Так-как Ваши учетные данные удалены"));
                        }
                        if ($UserData->us_role == User::ROLE_BANNED) {
                            throw new Exception(Lng::_("FALSE:Объявление добавить не возможно. Так-как Ваша учетная запись заблокирована"));
                        }

                        //Устанавливаем ID пользователя
                        $us_id = $UserData->us_id;
                    } //Иначе, выводим сообщение что пароль не верный
                    catch (Exception $e) {
                        $error_pass_code = $e->getMessage();
                    }
                } //Иначе, регистрируем пользователя в БД
                catch (Exception_CheckData $e) {
                    //Определяем что пользователь только что зарегистрирован
                    $is_registration = true;

                    //Проверяем, на находится ли имя пользователя в листе запрещенных имен
                    if (Modules_Users_Models_Users::isBlackName($_POST['ad_name']) == TRUE) {
                        throw new Exception_CheckData(Lng::_('FALSE:Регистрация с выбранным именем запрещена'));
                    }

                    //Проверяем, был ли раньше зарегистрирован email или нет
                    if ($this->getModel("Users", "Users")->isExistsEmail($_POST['ad_email'])) {
                        throw new Exception_CheckData(Lng::_("FALSE:Пользователь с указанным почтовым ящиком уже зарегистрирован. Выберете другой email для регистрации."));
                    }

                    //Формируем пароль пользователю
                    $password = Str::randomText(8, "string", "int", "symbol");

                    //Добавляем пользователя в БД
                    @                    parent::getModel("Users", "Users")->addUser(
                        $_POST['ad_name'],
                        $password,
                        $_POST['ad_email']
                    );
					
					@                    parent::getModel("Subscribe") -> addSubscribe($_POST['ad_email'],0);

                    //Получаем данные по только что созданному логину
                    $UserData = parent::getModel("Users", "Users")->getUserByEmail($_POST['ad_email']);
                    //Устанавливаем ID пользователя
                    $us_id = $UserData->us_id;
                }

                //Если пароль был веден не верно, отображаем ошибку
                if ($error_pass_code) {
                    throw new Exception_CheckData($error_pass_code);
                }

                //Если указан сайт, то проверяем наличие "http://"
                if ($_POST['ad_site']) {
                    $_POST['ad_site'] = Str::http($_POST['ad_site']);
                }
                $ad_is_lock = (int)$Settings->general->isPublicAdAfterAdd;

                //Блокируем, если стоит проверка на публикацию объявлений с сылками в теле объявлений
                if ((intval($Settings->general->isPublicAdWithLink) == 0) && (sizeof(Security::searchUrl($_POST['ad_text'])) > 0)) {
                    $ad_is_lock = 1;
                }

                //Блокируем, если стоит проверка на подтверждение подачи объявления по Email
                if (intval($Settings->general->isCheckAddAdByEmail) == 1) {
                    $ad_is_lock = 1;
                }

                //Формируем уникальный код доступа к объявлению
                $ad_code = md5(uniqid(time()));
                //Добавляем объявление в БД
                parent::getModel("Ad")->addAd(
                    $us_id,
                    $_POST['ad_name'],
                    $_POST['ad_email'],
                    $_POST['ad_phone'],
                    $_POST['ad_site'],
                    $_POST['ad_title'],
                    $_POST['ad_text'],
                    $_POST['ad_region_id'],
                    $_POST['cat_id'],
                    $ad_foto = '',
                    $ad_is_lock,
                    $_POST['ad_keep'],
                    $ad_code,
                    $_POST['ad_sum']
                );

                //Получаем id только что созданного объявления
                $last_ad_id = parent::getModel("Ad")->getLastId();

                if ($last_ad_id && ($_FILES['ad_foto']['size'] || sizeof($ad_fotos_ar) > 0)) {
                    Site::setTimeLimit(0);

                    //Создаем каталог дат
                    $img_date_dir = parent::getLib()->createImgPath(Modules_Board_Controllers_Index::PATH_DIR_NORMAL);
                    //Если загрузили фотографию
                    if ($_FILES['ad_foto']['size']) {
                        try {
                            //Загружаем и сохраняем фото
                            parent::getLib()->uploadAndSaveMainFoto(
                                parent::getModel("Ad"),
                                $last_ad_id,
                                $img_date_dir
                            );
                        } catch (Exception $e) {
                            $is_error_foto = true;
                        }
                    }
                    //Загружаем дополнительные изображения
                    if (sizeof($ad_fotos_ar) > 0) {
                        //Расчитываем, сколько изображений можно еще загрузить
                        $allow_uploads = Modules_Board_Controllers_Index::IMAGES_UPLOADED_COUNT;
                        $allow_uploads--;
                        parent::getLib()->uploadAndSaveAddFoto($last_ad_id, $ad_fotos_ar, $img_date_dir, $allow_uploads);
                    }
                }

                //Отправляем админу и пользователю письма
                if ($is_registration == TRUE) {
                    //Отправляем письмо пользователю с объявлением и регистрацией
                    parent::getLib("Mail")->userAddAdRegistr(parent::getTemplate("mail.user_us_add_ad_registr"), $_POST['ad_name'], $password, $_POST['ad_email'], $_POST['ad_title'], $ad_code);
                } else {
                    //Отправляем письмо пользователю с объявлением
                    parent::getLib("Mail")->userAddAd(parent::getTemplate("mail.user_us_add_ad"), $_POST['ad_name'], $_POST['ad_email'], $_POST['ad_title'], $ad_code);
                }

                //Если нужно, отправляем администратору уведомление о подаче объявления
                if (intval($Settings->general->isSendMailAdminAfterAdAdd) == 1) {
                    //Отправляем письмо админу
                    parent::getLib("Mail")->adminUserAddAd(parent::getTemplate("mail.admin_us_add_ad"), $_POST['ad_name'], $_POST['ad_email'], $_POST['ad_title'], $_POST['ad_text'], $ad_code);
                }

                //В зависимости от ошибки, отображаем то или иное сообщение
                if ($is_error_foto == TRUE) {
                    parent::redirect(Lng::_("TRUE:Объявление сохранено, но изображение загрузить не удалось. Проверьте, подходит ли изображение к загрузке"), "index.php?mod=board&go=add&cat_id=" . $cat_id);
                } else {
                    parent::redirect(Lng::_("TRUE:Ваше объявление успешно добавлено. Оно будет размещено на сайте сразу же, после проверки. Посмотреть объявление можно в " . Helper_HTML::anchor('index.php?mod=users', 'личном кабинете') . ". Пароль для входа выслан на указанный email."), "index.php?mod=board&go=add&cat_id=" . $cat_id);
                }
            } catch (Exception_CheckData $e) {
                parent::setMessage($e->getMessage());
            }
        }
        Site::addSkinVar('title', Lng::_('Создание нового объявления'));

        //Получаем данные всех категорий и формируем с них дерево
        $cat_ar = parent::getLib('Catch')->getCatAr();

        //Проверяем существование выбранной категории
        $check_cat_ar = Category::getPathWayAr($cat_ar, $cat_id);

        try {
            CheckData::existsDataArray($check_cat_ar);
        } catch (Exception_CheckData $e) {
            throw new Exception_Message(Lng::_('Выбранная Вами рубрика отсутствует'), 1);
        }
        if (isset($_POST['password']) == FALSE) {
            //Проверяем дубликат логина в БД
            Element_Autochecker::get("#ad_email", "index.php?mod=board.user&go=aj_emailchecker", 3);
        } else {
            $this->view->password = TRUE;
        }

        //Подключаем скрипт автодополнения городов
        Factory::jsCode('var sys_images_count = ' . Modules_Board_Controllers_Index::IMAGES_UPLOADED_COUNT);
        Factory::js('/scripts/modules/board/img.js');

        //Подключаем скрипт маски номеров телефона
        Factory::js('/scripts/jquery/jquery.maskedinput.js');

        //Полчаем path way
        $this->view->path_way = parent::getLib()->getPathWayLastBold($cat_ar, $cat_id);
        $this->view->cat_id = $cat_id;
        //Получаем список городов
        $this->view->city_ar = parent::getModel('city', 'city')->getListCityes();
    }

    /**
     * Правила публикации объявлений
     *
     */
    public function ruleAction()
    {
        Site::addSkinVar('title', Lng::_('Правила публикации объявлений'));

        $this->view->rules = parent::getModel()->getTextRule();
    }

    /**
     * Правила публикации объявлений
     *
     */
    public function paysAction()
    {
        Site::addSkinVar('title', Lng::_('Повысить эффективность объявлений на сайте DNP.dp.ua'));

        $this->view->pays = parent::getModel()->getTextPays();
    }

    /**
     * Просмотр объявления
     *
     */
    public function adAction()
    {
        //Первоначальная установка данных
        $ad_id = Request::getGet("ad_id", "int", 0);
        $this->view->is_notepad = TRUE;

        //Подключаем галерею
        Factory::fancyBox('.ad_foto');

        //Сохраняем показ
        parent::getLib()->setCountShows(parent::getModel("Ad"), $ad_id);

        //Получаем данные всех категорий и формируем с них дерево
        $cat_ar = parent::getLib('Catch')->getCatAr();
        $AdData = parent::getModel("Ad")->getAdById($ad_id);

        //Если данные у объявления отсутствуют, отображаем страницу 440
        try {
            CheckData::existsDataObject($AdData);
        } catch (Exception_CheckData $e) {
            throw new Exception_440();
        }

        //Если объявление заблокировано, отображаем страницу 440
        if ($AdData->ad_is_lock) {
            throw new Exception_440();
        }

        //ОПРЕДЕЛЯЕМ ОБЪЯВЛЕНИЯ КОТОРЫЕ МОГУТ ЗАИНТЕРЕСОВАТЬ ПОЛЬЗОВАТЕЛЯ
        //Подключаем шаблон оформления
        $Phtml = parent::getTemplate("view.similarad");
        //Получаем объявления текущей рубрики
        $SimilaradAr = $SimilaradAr_ = parent::getModel("Ad", "Board")->getAdForSimilarByCatIdLimit($AdData->cat_id, 10);
        unset($SimilaradAr_[$AdData->ad_id]);
        //$Phtml -> SimilAdAr = parent::getLib() -> getSimilarAd($Lala -> ad_title,$SimilaradAr_);
        $Phtml->SimilAdAr = $SimilaradAr_;
        $this->view->similarad_str = $Phtml->getView();

        //Определяем и формируем ссылки для предыдущего и следующего объявлений
        ksort($SimilaradAr);
        $this->view->previous_ad_id = false;
        $this->view->following_ad_id = false;
        foreach ($SimilaradAr as $SimilarAd) {
            if ($AdData->ad_id > $SimilarAd->ad_id) {
                $this->view->previous_ad_id = $SimilarAd->ad_id;
                $this->view->previous_ad_title = $SimilarAd->ad_title;
            } else if ($AdData->ad_id < $SimilarAd->ad_id) {
                if (!$this->view->following_ad_id) {
                    $this->view->following_ad_id = $SimilarAd->ad_id;
                    $this->view->following_ad_title = $SimilarAd->ad_title;
                }
            }
        }

        //Определяем доступ к установке рейтинга балов
        $is_add_rating = isset($_COOKIE['modBoard_rating'][$ad_id]) ? false : true;

        //Подключаем компонент рейтинга
        $this->view->rating = parent::getComponent("Rating", $this->com_group_rating)->showRating($ad_id, "index.php?mod=board.ad&go=aj_rating", $is_add_rating);

        //Получаем настройки модуля
        $this->view->BoardSett = parent::getModel("Settings")->getConfig();

        //Полчаем path way
        $this->view->path_way = parent::getLib()->getPathWay($cat_ar, $AdData->cat_id);
        $this->view->Ad = $AdData;
        $this->view->disqus_url = URL::site("index.php?mod=board&go=ad&ad_id=" . $AdData->ad_id, $AdData->ad_title);

        $page_title = $AdData->ad_meta_title;
        if ($AdData->ad_meta_title == FALSE) {

            $page_title = $AdData->ad_title . ', ' . ($AdData->cat_title ? $AdData->cat_title : Lng::_('Днепропетровская область'));
        }
        $Cat = parent::getModel('category')->getCategoryById($AdData->cat_id);
        //Устанавливаем TITLE для странцы
        Site::addSkinVar('title', $page_title . ' - ' . $Cat->cat_title . ' на dnp.dp.ua');

        //Устанавливаем DESCRIPTION для страницы
        Site::setSkinVar('description', $Cat->cat_title . ': ' . $AdData->ad_title . ', цена ' . $AdData->ad_sum . ' грн., ' . ($AdData->cat_title ? $AdData->cat_title : Lng::_('Днепропетровск')) . ', Днепропетровская область. Бесплатные объявления на сайте dnp.dp.ua');

        //Формируем ключевые слова
        if ($AdData->ad_text) {
            $ad_text_ar = array_map("trim", explode(" ", strtr($AdData->ad_text, array(
                "\r" => "", "\n" => "", "." => "", "," => "", "!" => "",
                ")" => "", "(" => "", "'" => "", "\"" => "", "*" => "",
                "@" => "", "#" => "", "$" => "", "%" => "", "^" => "",
                "?" => "", "&" => "", "[" => "", "]" => "", "=" => "",
                "+" => "", "-" => "", ":" => "", ";" => "", "|" => "",
            ))));

            $keywords_ar = array();
            $i = $j = 0;
            foreach ($ad_text_ar as $word) {
                if (Str::strlen($word) > 6) {
                    if ($j % 2) {
                        $keywords_ar[$i] .= ' ' . $word;
                        $i++;
                    } else {
                        $keywords_ar[$i] = $word;
                    }
                    $j++;
                }
            }

            $keywords_ar = array_slice($keywords_ar, 0, 10);
            //Устанавливаем KEYWORDS для страницы
            Site::setSkinVar('keywords', join(", ", $keywords_ar));
        }

        //Получаем данные доп. изображений
        $this->view->ImagesAr = Models_Images::instance()->getListImagesByObjId($ad_id, Modules_Board_Controllers_Index::GROUP_IMG);
        $this->view->comment_disqus_shortname = Registry::get('Config')->comments->comment_disqus_shortname;
        Factory::js('/scripts/modules/board/ad.js');
        Element_Thickbox::get();

        Site::addSkinVar('canonical', URL::site('index.php?mod=board&go=ad&ad_id=' . $AdData->ad_id, $AdData->ad_title));
		Site::addSkinVar('image_src', (Modules_Board_Controllers_Index::PATH_VIEW_THUMB . $AdData->ad_foto));
		
		//is_file(Modules_Board_Controllers_Index::PATH_DIR_NORMAL . $AdData->ad_foto
    }

    /**
     * Выбираем рубрику
     *
     */
    public function selectAction()
    {
        //Ограничеваем доступ к контроллеру
        User::checkPrivilegesPage(array(User::ROLE_GUEST), TRUE);

        Site::addSkinVar('title', Lng::_('Подать объявление'));

        //Получаем данные для формирования списка рубрик в виде таблицы
        $DataSelect = parent::getLib("Data")->getSelectActionData(parent::getModel("Category"));

        //Устанавливаем ссылку вывода таблицы с рубриками
        $this->view->link_aj_select = "index.php?mod=board&go=aj_select&cat_id=";
        //Отображаем меню модуля
        $this->view->is_show_mod_menu = true;

        //Устанавливаем ссылки для таблицы с рубриками
        $this->view->link_cat = "index.php?mod=board&go=add&cat_id=";

        $this->view->cat_ar = $DataSelect->cat_ar;
        $this->view->count_ar = $DataSelect->count_ar;
        $this->view->index = 1;
    }

    /**
     * Удаляет объявление
     *
     */
    public function deleteAction()
    {
        $code = Request::getGet('code');
        if ($code == '') {
            throw new Exception_Message(Lng::_('Объявление отсутствует'), 1);
        }

        //Проверяем сущетвует ли удаляемое объявление
        $AdData = parent::getModel("Ad")->getAdByCode($code);
        try {
            CheckData::existsDataObject($AdData, Lng::_('Удаляемое Вами объявление отсутствует'));
        } catch (Exception_CheckData $e) {
            throw new Exception_Message($e->getMessage(), 1);
        }

        try {
            //Удаляем фото
            if (is_file(Modules_Board_Controllers_Index::PATH_DIR_NORMAL . $AdData->ad_foto)) {
                Modules_Board_Models_Ad::deleteImg($AdData->ad_foto);
            }

            //Удаляем доп. фотографии
            parent::getLib("Data")->deleteAddFotos($AdData->ad_id);

            //Удаляем рейтинг объявлений
            parent::getComponent("Rating", $this->com_group_rating)->getModel()->deleteRatingById($AdData->ad_id);

            //Удаляем объявление с БД
            parent::getModel("Ad")->deleteAdById($AdData->ad_id);
        } catch (Exception $e) {
            throw new Exception_Message(Lng::_('Во время удаления объявления возникла ошибка'));
        }
        parent::setMessage(Lng::_("TRUE:Ваше объявление успешно удалено"));
    }

    /**
     * Отображает страницу с фильтром данных
     *
     */
    public function filterAction()
    {
        //Определяем номер текущей страницы
        $page = BreakPage::getPageNum();

        //Получаем данные выбранных рубрик и подрубрик
        $cat_sel_ar = array_map('intval', Request::getGet('c', 'array', array()));
        //Искомая фраза
        $sr_text = Request::getGet('t', 'Security::filterFull', NULL);
        //Выбранный регион
        $sr_region_id = Request::getGet('r', 'int', NULL);

        //Массив выбранных категорий
        $c_ar = array();
        //ID последней выбранной в списке категории
        $cat_last_id = 0;
        //Определяем ID последней рубрики
        foreach ($cat_sel_ar as $cat_id) {
            if ($cat_id > 0) {
                $cat_last_id = $cat_id;
                $c_ar[] = "c[]=" . $cat_id;
            }
        }

        //--> Определяем дочерние категории текущей
        //Получаем данные всех категорий и формируем с них дерево
        $cat_ar = parent::getLib('Catch')->getCatAr();

        //Получаем часть дерева, для формирования подрубрик
        $cat_ar = Category::getTreeByDepth($cat_ar, $cat_last_id, 1000);

        //Переформировываем массив категорий для получения по ним объявлений
        $cats_ar = parent::getLib()->prepareCatData($cat_ar);
        $cats_ar[$cat_last_id] = $cat_last_id;

        //ПЕРЕДАЕМ ДАННЫЕ В ВИД
        parent::setView('./modules/board/views/index/search.phtml');

        //Ищем унжые данные в БД
        $this->view->AdAr = parent::getModel("Ad")->filterAdBy(
            $sr_text,
            $sr_region_id,
            $cats_ar,
            Request::getGet('s1', 'int'),
            Request::getGet('s2', 'int'),
            (($page - 1) * $this->ad_on_page),
            $this->ad_on_page
        );
        //Определяем количество найденных данных
        $ad_count = parent::getModel("Ad")->filterCountAdBy(
            $sr_text,
            $sr_region_id,
            $cats_ar,
            Request::getGet('s1', 'int'),
            Request::getGet('s2', 'int')
        );


        //Делаем разбивку по странично
        BreakPage::$is_url = false;
        $this->view->breakpage = BreakPage::getPages($ad_count, $this->ad_on_page, $page, "index.php?mod=board&go=filter&t=" . $sr_text . "&r=" . $sr_region_id . (sizeof($c_ar) > 0 ? "&" . join('&', $c_ar) : "") . "&page=", false);
    }

    /**
     * Поиск объявлений
     *
     */
    public function searchAction()
    {
        //Определяем номер текущей страницы
        $page = BreakPage::getPageNum();

        $t = Request::getGet('t', 'string', '');
        $r = Request::getGet('r', 'string', '');

        if (Str::strlen($t) <= 2) {
            parent::redirect(Lng::_("FALSE:Искомое объявление должно быть больше 2-х символов"), "index.php?mod=board");
        }

        //ПЕРЕДАЕМ ДАННЫЕ В ВИД
        //Ищем унжые данные в БД
        $this->view->AdAr = parent::getModel("Ad")->searchAdBy($t, $r, (($page - 1) * $this->ad_on_page), $this->ad_on_page);
        //Определяем количество найденных данных
        $ad_count = parent::getModel("Ad")->searchCountAdBy($t, $r);
        //Делаем разбивку по странично

        BreakPage::$is_url = FALSE;
        $this->view->breakpage = BreakPage::getPages($ad_count, $this->ad_on_page, $page, "index.php?mod=board&go=search&r=" . rawurlencode($r) . "&t=" . rawurlencode($t) . "&page=", false);
        BreakPage::$is_url = TRUE;
    }

    /**
     * Страница со списком VIP объявлений (Выключим вообще пока шо)
     *
     */
    /*public function vipAction()
    {
        //Определяем номер текущей страницы
        $page = BreakPage::getPageNum();
        //Ищем унжые данные в БД
        $this -> view -> AdAr = parent::getModel("Ad") -> getListVipAdByLimitUnlock((($page-1)*$this -> ad_on_page),$this -> ad_on_page);
        //Определяем количество найденных данных
        $ad_count = parent::getModel("Ad") -> getCountVipAd();
        //Делаем разбивку по странично
        $this -> view -> breakpage = BreakPage::getPages($ad_count,$this -> ad_on_page,$page,"index.php?mod=board&go=vip&page=",true);
    }*/

    /**
     * Выполняет активацию объявления
     * @throws Exception_Message
     */
    public function activationAction()
    {
        $code = Request::getGet('code');
        if ($code == '') {
            throw new Exception_Message(Lng::_('Объявление отсутствует'), 1);
        }

        //Проверяем сущетвует ли удаляемое объявление
        $Ad = parent::getModel("Ad")->getAdByCode($code);

        if (intval(Modules_Board_Models_Settings::instance()->getConfig()->general->isPublicAdWithLink) == 0 && sizeof(Security::searchUrl($Ad->ad_text)) > 0) {
            parent::redirect(Lng::_('FALSE:Объявление не может быть опубликовано. Т.к. на сайте запрещено публиковать объявления с ссылками.'), '/', FALSE);
        }

        try {
            CheckData::existsDataObject($Ad, Lng::_('Объявление отсутствует'));
        } catch (Exception_CheckData $e) {
            throw new Exception_Message($e->getMessage(), 1);
        }

        parent::getModel("Ad")->updateAdLockedByCode($code, 0);

        parent::redirect(Lng::_("TRUE:Объявление опубликовано"), '/', FALSE);
    }

    /********************************************************************************************************************/
    /************************************************** AJAX METHODS ****************************************************/
    /********************************************************************************************************************/

    /**
     * Возвращает данные выбранной категори
     *
     */
    public function aj_filter_catAction()
    {
        CheckData::isAjax();

        try {
            //Получаем данные выбранной рубрики
            $cat_id = Request::getGet('cat_id', 'int', 0);

            if ($cat_id > 0) {
                $c_ar = parent::getModel('Category', 'Board')->getCategoryByParentAr(array($cat_id));
                if (isset($c_ar[$cat_id]) && sizeof($c_ar[$cat_id]) > 0) {
                    $cat_ar = array(Lng::_('- выберете рубрику -')) + $c_ar[$cat_id];
                    die("<div class=\"field\">" .
                        Helper_Form::select('c[' . $cat_id . ']', $cat_ar, null, array('class' => 'select mod_board-filter_select', 'onchange' => 'modBoard_filterSelectCat(this)'))
                        . "</div>\n");
                }
            }
        } catch (Exception $e) {

        }
        exit;
    }

    /**
     * По аякс запросу возвращает таблицу с рубриками
     *
     */
    public function aj_selectAction()
    {
        CheckData::isAjax();

        //Получаем данные для формирования списка рубрик в виде таблицы
        $DataSelect = parent::getLib("Data")->getSelectActionData(parent::getModel("Category"), Request::getGet("cat_id", "int"));

        //Устанавливаем ссылки для таблицы с рубриками
        $this->view->link_cat = "index.php?mod=board&go=add&cat_id=";

        $this->view->cat_ar = $DataSelect->cat_ar;
        $this->view->count_ar = $DataSelect->count_ar;
        $this->view->index = $_GET['index'] + 1;

        die(parent::getView());
    }

    /**
     * Делает автодополнение городов
     *
     */
    public function aj_cityAction()
    {
        CheckData::isAjax();

        $Cityes = parent::getModel("City", "City")->searchCityByTitle($_GET['q']);
        foreach ($Cityes as $City) {
            echo $City->cat_title . "\n";
        }
        exit;
    }
}