<?php defined("MOMENT_BOARD") or die("Access denied");

/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Контроллер "Доска объявлений, User", для гостя
 */
class Modules_Board_Controllers_IndexUser extends Modules_Board_Controllers_Index
{
    /**
     * Список объявлений
     *
     */
    public function indexAction()
    {
        //Ограничеваем доступ к контроллеру
        User::checkPrivilegesPage(array(User::ROLE_USER, User::ROLE_ADMIN), TRUE);

        //Подключаем подсказки
        Element_Tooltip::get("span.skin-tooltip");

        Factory::zebra();
        //Получаем объявления пользователя
        $this->view->Ads = parent::getModel("Ad")->getAdByUsId(User::get("id"));

        Site::addSkinVar("title", Lng::_('Мои объявления'));
    }

    /**
     * Выбираем рубрику
     *
     */
    public function selectAction()
    {
        //Ограничеваем доступ к контроллеру
        User::checkPrivilegesPage(array(User::ROLE_USER, User::ROLE_ADMIN), TRUE);

        Site::addSkinVar('title', Lng::_('Подать объявление'));

        //Насильно подключаем вид
        parent::setView("./modules/board/views/index/select.phtml");

        //Получаем данные для формирования списка рубрик в виде таблицы
        $DataSelect = parent::getLib("Data")->getSelectActionData(parent::getModel("Category"));

        //ОПИСАНИЕ:1 Если есть ad_id значит меняем ссылки рубрик
        //Возможны два варианта:
        //1. Создание объявления;
        //2. Редактирование объявления. Во втором сулчае $ad_id > 0;
        $ad_id = Request::getGet("ad_id", "int", false);

        //Если $ad_id > 0 значит мы меняем рбрику объявлению, а соответственно нужно подменить ссылки
        if ($ad_id > 0) {
            //Устанавливаем ссылку вывода таблицы с рубриками
            $this->view->link_aj_select = "index.php?mod=board.user&go=aj_select&ad_id=" . $ad_id . "&cat_id=";

            //Устанавливаем ссылки для таблицы с рубриками
            $this->view->link_cat = "index.php?mod=board.user&go=edit&ad_id=" . $ad_id . "&cat_id=";
        } else {
            //Устанавливаем ссылку вывода таблицы с рубриками
            $this->view->link_aj_select = "index.php?mod=board.user&go=aj_select&cat_id=";

            //Устанавливаем ссылки для таблицы с рубриками
            $this->view->link_cat = "index.php?mod=board.user&go=add&cat_id=";
        }

        //НЕ отображаем меню модуля
        $this->view->is_show_mod_menu = false;

        $this->view->cat_ar = $DataSelect->cat_ar;
        $this->view->count_ar = $DataSelect->count_ar;
        $this->view->index = 1;
    }

    /**
     * Создаем объявление
     *
     */
    public function addAction()
    {
        //Ограничеваем доступ к контроллеру
        User::checkPrivilegesPage(array(User::ROLE_USER, User::ROLE_ADMIN), TRUE);

        //Получаем данные cat_id
        $cat_id = Request::getGet("cat_id", "int", Request::getPost("cat_id", "int"));

        if (Request::isPost()) {
            try {
                //Установка пост данных формы, на тот случай если возникла ошибка
                $this->view->ad_name = $_POST['ad_name'];
                $this->view->ad_email = $_POST['ad_email'];
                $this->view->ad_phone = $_POST['ad_phone'];
                $this->view->ad_site = $_POST['ad_site'];
                $this->view->ad_title = $_POST['ad_title'];
                $this->view->ad_text = $_POST['ad_text'];
                $this->view->cat_id = $_POST['cat_id'];
                $this->view->ad_keep = $_POST['ad_keep'];
                $this->view->ad_region_id = (int)$_POST['ad_region_id'];
                $this->view->ad_sum = floatval($_POST['ad_sum']);

                //Проверяем полученные данные
                parent::getLib()->checkAdData(parent::getModel("Category"), array(
                    'check_captcha' => TRUE
                ));

                //Выполняем валидацию загружаемым файлам
                $ad_fotos_ar = parent::getLib()->validateFotos();

                //Если указан сайт, то проверяем наличие "http://"
                if ($_POST['ad_site']) {
                    $_POST['ad_site'] = Str::http($_POST['ad_site']);
                }
                //Получаем данные настроек
                $Settings = parent::getModel("Settings")->getConfig();
                $ad_is_lock = (int)$Settings->general->isPublicAdAfterAdd;

                //Если стоит проверка на публикацию объявлений с сылками в теле объявлений
                if ((intval($Settings->general->isPublicAdWithLink) == 0) && (sizeof(Security::searchUrl($_POST['ad_text'])) > 0)) {
                    $ad_is_lock = 1;
                }

                //Формируем уникальный код доступа к объявлению
                $ad_code = md5(uniqid(time()));
                //Добавляем объявление в БД
                parent::getModel("Ad")->addAd(
                    User::get("id"),
                    $_POST['ad_name'],
                    $_POST['ad_email'],
                    $_POST['ad_phone'],
                    $_POST['ad_site'],
                    $_POST['ad_title'],
                    $_POST['ad_text'],
                    $_POST['ad_region_id'],
                    $_POST['cat_id'],
                    $ad_foto = '',
                    $ad_is_lock,
                    $_POST['ad_keep'],
                    $ad_code,
                    $_POST['ad_sum']
                );

                //Получаем id только что созданного объявления
                $last_ad_id = parent::getModel("Ad")->getLastId();

                if ($last_ad_id && ($_FILES['ad_foto']['size'] || sizeof($ad_fotos_ar) > 0)) {
                    Site::setTimeLimit(0);

                    //Создаем каталог дат
                    $img_date_dir = parent::getLib()->createImgPath(Modules_Board_Controllers_Index::PATH_DIR_NORMAL);
                    //Если загрузили фотографию
                    if ($_FILES['ad_foto']['size']) {
                        if ($last_ad_id) {
                            try {
                                //Загружаем и сохраняем фото
                                parent::getLib()->uploadAndSaveMainFoto(
                                    parent::getModel("Ad"),
                                    $last_ad_id,
                                    $img_date_dir
                                );
                            } catch (Exception $e) {
                                parent::redirect(Lng::_("TRUE:Объявление сохранено, но изображение загрузить не удалось. Проверьте, подходит ли изображение к загрузке"), "index.php?mod=board.user&go=add&cat_id=" . $cat_id);
                            }
                        }
                    }
                    //Загружаем дополнительные изображения
                    if (sizeof($ad_fotos_ar) > 0) {
                        //Расчитываем, сколько изображений можно еще загрузить
                        $allow_uploads = Modules_Board_Controllers_Index::IMAGES_UPLOADED_COUNT;
                        $allow_uploads--;
                        parent::getLib()->uploadAndSaveAddFoto($last_ad_id, $ad_fotos_ar, $img_date_dir, $allow_uploads);
                    }
                }

                parent::getLib("Mail")->userAddAd(parent::getTemplate("mail.user_us_add_ad"), $_POST['ad_name'], $_POST['ad_email'], $_POST['ad_title'], $ad_code);

                //Если нужно, отправляем администратору уведомление о подаче объявления
                if (intval($Settings->general->isSendMailAdminAfterAdAdd) == 1) {
                    //Отправляем письмо админу
                    parent::getLib("Mail")->adminUserAddAd(parent::getTemplate("mail.admin_us_add_ad"), $_POST['ad_name'], $_POST['ad_email'], $_POST['ad_title'], $_POST['ad_text'], $ad_code);
                }

                parent::redirect(Lng::_("TRUE:Ваше объявление успешно добавлено. Оно будет размещено на сайте сразу же, после проверки. Посмотреть объявление можно в " . Helper_HTML::anchor('index.php?mod=users', 'личном кабинете') . "."), "index.php?mod=board.user&go=add&cat_id=" . $cat_id);
            } catch (Exception_CheckData $e) {
                parent::setMessage($e->getMessage());
            }
        } else {
            //Устанавливаем данные по умолчанию
            $this->view->ad_name = User::get("name");
            $this->view->ad_email = User::get("email");
        }

        Site::addSkinVar('title', Lng::_('Создание нового объявления'));

        //Получаем данные всех категорий и формируем с них дерево
        $cat_ar = parent::getLib('Catch')->getCatAr();

        //Проверяем существование выбранной категории
        $check_cat_ar = Category::getPathWayAr($cat_ar, $cat_id);

        try {
            CheckData::existsDataArray($check_cat_ar);
        } catch (Exception_CheckData $e) {
            throw new Exception_Message(Lng::_('Выбранная Вами рубрика отсутствует'), 1);
        }

        //Подключаем скрипт автодополнения городов
        Factory::jsCode('var sys_images_count = ' . Modules_Board_Controllers_Index::IMAGES_UPLOADED_COUNT);
        Factory::js('/scripts/modules/board/img.js');

        //Подключаем скрипт маски номеров телефона
        Factory::js('/scripts/jquery/jquery.maskedinput.js');

        //Полчаем path way
        $this->view->path_way = parent::getLib()->getPathWayLastBold($cat_ar, $cat_id);
        $this->view->cat_id = $cat_id;
        //Получаем список городов
        $this->view->city_ar = parent::getModel('city', 'city')->getListCityes();
    }

    /**
     * Редактируем объявление
     *
     */
    public function editAction()
    {
        //Ограничеваем доступ к контроллеру
        User::checkPrivilegesPage(array(User::ROLE_USER, User::ROLE_ADMIN), TRUE);

        $ad_id = Request::getGet("ad_id", "int");
        $cat_id = Request::getGet("cat_id", "int", Request::getPost("cat_id", "int"));

        //Проверяем доступ к объявлению
        if (!parent::getModel("Ad")->checkAccessUserToAd(User::get("id"), $ad_id)) {
            parent::redirect(Lng::_("FALSE:Операция запрещена"), "index.php?mod=board.user");
        }

        if (Request::isPost()) {
            try {
                //Устанавливаем ID региона в вид, чтобы еге не передавать через GET запросы
                $this->view->cat_id = $_POST['cat_id'];

                //Проверяем полученные данные
                parent::getLib()->checkAdData(parent::getModel("Category"), array(
                    'check_captcha' => FALSE
                ));

                //Выполняем валидацию загружаемым файлам
                $ad_fotos_ar = parent::getLib()->validateFotos();

                //Если указан сайт, то проверяем наличие "http://"
                if ($_POST['ad_site']) {
                    $_POST['ad_site'] = Str::http($_POST['ad_site']);
                }
                //Получаем данные настроек
                $Settings = parent::getModel("Settings")->getConfig();
                $ad_is_lock = (int)$Settings->general->isPublicAdAfterEdit;

                //Если стоит проверка на публикацию объявлений с сылками в теле объявлений
                if ((intval($Settings->general->isPublicAdWithLink) == 0) && (sizeof(Security::searchUrl($_POST['ad_text'])) > 0)) {
                    $ad_is_lock = 1;
                }
                //Обновляем объявление
                parent::getModel("Ad")->updateAd(
                    $ad_id,
                    $_POST['ad_name'],
                    $_POST['ad_email'],
                    $_POST['ad_phone'],
                    $_POST['ad_site'],
                    $_POST['ad_title'],
                    $_POST['ad_text'],
                    $_POST['ad_region_id'],
                    $_POST['cat_id'],
                    $ad_is_lock,
                    $_POST['ad_keep'],
                    array(
                        'ad_sum' => floatval($_POST['ad_sum']),
                    )
                );

                if ((isset($_FILES['ad_foto']) && $_FILES['ad_foto']['size']) || sizeof($ad_fotos_ar) > 0) {
                    Site::setTimeLimit(0);

                    //Создаем каталог дат
                    $img_date_dir = parent::getLib()->createImgPath(Modules_Board_Controllers_Index::PATH_DIR_NORMAL);

                    //Если загрузили фотографию
                    if (isset($_FILES['ad_foto']) && $_FILES['ad_foto']['size']) {
                        try {
                            //Загружаем и сохраняем фото
                            parent::getLib()->uploadAndSaveMainFoto(
                                parent::getModel("Ad"),
                                $ad_id,
                                $img_date_dir
                            );
                        } catch (Exception $e) {
                            parent::redirect(Lng::_("TRUE:Объявление сохранено, но изображение загрузить не удалось. Проверьте, подходит ли изображение к загрузке"), "index.php?mod=board.user&go=edit&ad_id=" . $ad_id);
                        }
                    }

                    //Загружаем дополнительные изображения
                    if (sizeof($ad_fotos_ar)) {
                        //Определяем, сколько изображений уже загружено
                        $upload_img = Models_Images::instance()->getCountImageByObjId($ad_id, Modules_Board_Controllers_Index::GROUP_IMG);

                        //Расчитываем, сколько изображений можно еще загрузить
                        $allow_uploads = Modules_Board_Controllers_Index::IMAGES_UPLOADED_COUNT - $upload_img;
                        //Вычитаем главное изображение
                        $allow_uploads--;
                        parent::getLib()->uploadAndSaveAddFoto($ad_id, $ad_fotos_ar, $img_date_dir, $allow_uploads);
                    }
                }

                parent::getLib("Mail")->adminUserEditdAd(parent::getTemplate("mail.admin_us_edit_ad"), $_POST['ad_name'],
                    $_POST['ad_email'], $_POST['ad_title'], $_POST['ad_text'], $ad_code);


                parent::redirect(Lng::_("TRUE:Объявление отредактировано"), "index.php?mod=board.user&go=edit&ad_id=" . $ad_id);
            } catch (Exception_CheckData $e) {
                parent::setMessage($e->getMessage());
            }
        }
        Site::addSkinVar('title', Lng::_('Редактирование объявления'));

        //Получаем данные всех категорий и формируем с них дерево
        $cat_ar = parent::getLib('Catch')->getCatAr();
        //Получаем данные объявления
        $Ad = parent::getModel("Ad")->getAdById($ad_id);

        //Если ранее $cat_id не получили, значит устанавливаем рубрику с объявления
        $cat_id = $cat_id ? $cat_id : $Ad->cat_id;

        //Проверяем существование выбранной категории
        $check_cat_ar = Category::getPathWayAr($cat_ar, $cat_id);

        try {
            CheckData::existsDataArray($check_cat_ar);
        } catch (Exception_CheckData $e) {
            throw new Exception_Message(Lng::_('Выбранная Вами рубрика отсутствует'), 1);
        }

        //Подключаем скрипт автодополнения городов
        Factory::jsCode('var sys_images_count = ' . Modules_Board_Controllers_Index::IMAGES_UPLOADED_COUNT);
        Factory::js('/scripts/modules/board/img.js');
        //Подключаем галерею
        Factory::fancyBox('.ad_foto');

        //Подключаем скрипт маски номеров телефона
        Factory::js('/scripts/jquery/jquery.maskedinput.js');

        //Полчаем path way
        $this->view->path_way = parent::getLib()->getPathWayLastBold($cat_ar, $cat_id);
        $this->view->Ad = $Ad;
        //Получаем список городов
        $this->view->city_ar = parent::getModel('city', 'city')->getListCityes();
        //Получаем данные доп. изображений
        $this->view->ImagesAr = Models_Images::instance()->getListImagesByObjId($ad_id, Modules_Board_Controllers_Index::GROUP_IMG);

        //В том случае, если данные не были получены посредством POST
        //устанавливаем в вид cat_id
        if (!Request::getPost("sub_ad", "bool", false)) {
            $this->view->cat_id = $cat_id;
        }
    }

    /**
     * Удаляем фотографию объявления
     *
     */
    public function deletefotoAction()
    {
        //Ограничеваем доступ к контроллеру
        User::checkPrivilegesPage(array(User::ROLE_USER, User::ROLE_ADMIN), TRUE);

        //Получаем id объявления
        $ad_id = Request::getGet("ad_id", "int", 0);
        $im_id = Request::getGet("im_id", "int", 0);

        //Проверяем доступ к объявлению
        if (parent::getModel("Ad")->checkAccessUserToAd(User::get("id"), $ad_id) == FALSE) {
            parent::redirect(Lng::_("FALSE:Операция запрещена"), "index.php?mod=board.user&go=edit&ad_id=" . $ad_id);
        }

        //Удаляем доп. фотографию
        if ($im_id > 0) {
            parent::getLib("Data")->deleteAddFoto($im_id, $ad_id);
        } //Удаляем основную офотографию
        else {
            parent::getLib("Data")->deleteFotoAdAction(parent::getModel("Ad"), $ad_id);
        }
        parent::redirect(Lng::_("TRUE:Фото объявления удалено"), "index.php?mod=board.user&go=edit&ad_id=" . $ad_id);
    }

    /**
     * Удаляет объявление
     *
     */
    public function deleteAction()
    {
        //Ограничеваем доступ к контроллеру
        User::checkPrivilegesPage(array(User::ROLE_USER, User::ROLE_ADMIN), TRUE);

        //Получаем id объявления
        $ad_id = Request::getGet("ad_id", "int", 0);

        //Проверяем доступ к объявлению
        if (parent::getModel("Ad")->checkAccessUserToAd(User::get("id"), $ad_id) == FALSE) {
            parent::redirect(Lng::_("FALSE:Операция запрещена"), "index.php?mod=board.user");
        }

        //Удаляем доп. фотографии
        parent::getLib("Data")->deleteAddFotos($ad_id);

        //Удаляем объявление
        parent::getLib("Data")->deleteAdAction(parent::getModel("Ad"), parent::getComponent("Rating", $this->com_group_rating), $ad_id);
        parent::redirect(Lng::_("TRUE:Объявление удалено"), "index.php?mod=board.user");
    }

    /**
     * Просматриваем объявление
     *
     */
    public function viewAction()
    {
        //Ограничеваем доступ к контроллеру
        User::checkPrivilegesPage(array(User::ROLE_USER, User::ROLE_ADMIN), TRUE);

        //Установка данндых
        $ad_id = Request::getGet("ad_id", "int");
        Site::addSkinVar("title", Lng::_('Просмотр объявления'));
        parent::setView('./modules/board/views/admin.ad/view.phtml');

        //Проверяем доступ к объявлению
        if (parent::getModel("Ad")->checkAccessUserToAd(User::get("id"), $ad_id) == FALSE) {
            parent::redirect(Lng::_("FALSE:Запрещено просматривать чужие объявления"), "index.php?mod=board.user");
        }

        $DataView = parent::getLib("Data")->getViewAdActionData(
            parent::getModel("Ad"),
            parent::getModel("Category"),
            $ad_id
        );
        $this->view->Ad = $DataView->Ad;
        $this->view->ad_keep = $DataView->ad_keep;
        $this->view->path_way = $DataView->path_way;
        //Получаем данные доп. изображений
        $this->view->ImagesAr = Models_Images::instance()->getListImagesByObjId($ad_id, Modules_Board_Controllers_Index::GROUP_IMG);
    }

    /********************************************************************************************************************/
    /************************************************** AJAX METHODS ****************************************************/
    /********************************************************************************************************************/

    /**
     * По аякс запросу возвращает таблицу с рубриками
     *
     */
    public function aj_selectAction()
    {
        //Ограничеваем доступ к контроллеру
        User::checkPrivilegesPage(array(User::ROLE_USER, User::ROLE_ADMIN), TRUE);

        CheckData::isAjax();

        //Насильно подключаем вид
        parent::setView("./modules/board/views/index/aj_select.phtml");

        //Получаем данные для формирования списка рубрик в виде таблицы
        $DataSelect = parent::getLib("Data")->getSelectActionData(parent::getModel("Category"), Request::getGet("cat_id", "int"));

        //Смотреть ОПИСАНИЕ:1
        $ad_id = Request::getGet("ad_id", "int", false);

        //Если $type = change значит меняем ссылки
        if ($ad_id) {
            //Устанавливаем ссылки для таблицы с рубриками
            $this->view->link_cat = "index.php?mod=board.user&go=edit&ad_id=" . $ad_id . "&cat_id=";
        } else {
            //Устанавливаем ссылки для таблицы с рубриками
            $this->view->link_cat = "index.php?mod=board.user&go=add&cat_id=";
        }

        $this->view->cat_ar = $DataSelect->cat_ar;
        $this->view->count_ar = $DataSelect->count_ar;
        $this->view->index = $_GET['index'] + 1;

        die(parent::getView());
    }

    /**
     * Проверка существования логина в БД Ajax способом
     *
     */
    public function aj_emailcheckerAction()
    {
        CheckData::isAjax();

        //Установка данных
        $email = Request::getGet('val', 'trim');

        try {
            CheckData::email($email);
        } catch (Exception $e) {
            die('<span class="nevernii-email">' . Lng::_('Email введен неверно') . '</span>');
        }

        //Проверяем наличие ЛОГИНА в БД
        if ($this->getModel("Users", "Users")->isExistsEmail($email)) {

            $c = '<div class="user-syshestvyet">';
            $c .= '<div class="email-zaniat">' . Lng::_('Email занят!') . '</div>';
            $c .= '<div class="esli-vash-email">' . Lng::_('Если это <strong>Ваш email</strong>, введите пароль.') . '</div>';
            $c .= '<div class="pass-zagolovok-ot">' . Lng::_('Пароль* ') . '</div>';
            $c .= Helper_Form::password('password', NULL, array('class' => 'text-password-formochka'));
            $c .= '</div>';
            $c .= Helper_HTML::anchor('index.php?mod=users&go=restore', Lng::_('Забыли пароль?'), array('class' => 'podat-ad-zabil-pass'));
            die($c);
        }
        die('<span class="svobodnii-email">' . Lng::_('Email свободен') . '</span>');
    }

    /**
     * Продление срока публикации объявления
     */
    public function keepAction()
    {
        //Ограничеваем доступ к контроллеру
        User::checkPrivilegesPage(array(User::ROLE_USER, User::ROLE_ADMIN), TRUE);

        //Обновляем дату
        Factory::getModel()->DB->setQuery("
                UPDATE
            `#__mod_board_ad` 
                SET
            `ad_keep` = '" . (time() + Str::DATE_WEEK) . "', `ad_date` = '" . time() . "'
                WHERE 
            `ad_id` = '" . Request::getGet("ad_id", "int") . "'
                AND
            `us_id` = '" . User::get('id') . "'",
            'Не удалось обновить срок публикации объявления'
        );
        //Получаем id объявления
        $ad_id = Request::getGet("ad_id", "int");
        //Получаем данные объявления
        $Ad = parent::getModel("Ad")->getAdById($ad_id);
        //Редиректим на страницу "Мои объявления" и выдаем сообщение
        parent::redirect(Lng::_("TRUE:Дата и срок публикации объявления " . Helper_HTML::anchor('index.php?mod=board&go=ad&ad_id=' . $Ad->ad_id, $Ad->ad_title) . " обновлены. Теперь объявление вверху списка."), "index.php?mod=board.user");
    }
}