<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Библиотека "Data" модуля "Board"
 */

class Modules_Board_Libs_Data
{
	/**
	 * Формирует данные для построения таблицы с рубриками (см. selectAction)
	 *
	 * @param object $ModelCat модель рубрик
	 * @param int $cat_id id родительской рубрики
	 * @return object
	 */
	public function getSelectActionData($ModelCat=null,$cat_id=0)
	{
		$Data = new stdClass();
		$Data -> cat_ar = array();
		$Data -> count_ar = array();
		
		$cat_ar = $ModelCat -> getCategoryByParentAr(array($cat_id));
		
		if(sizeof($cat_ar) > 0)
		{
			$Data -> cat_ar = reset($cat_ar);
			if(sizeof($Data -> cat_ar))
			{
				$Data -> count_ar = $ModelCat -> getCountChildCategoryByPCatAr(array_keys($Data -> cat_ar));
			}
		}
		
		return $Data;
	}
	
	/**
	 * Формирует данные для просмотра объявления (см. viewAction)
	 *
	 * @param object $ModelAd модель объявления
	 * @param object $ModelCat модел рубрики
	 * @param int $ad_id id объявления
	 * @return object
	 */
	public function getViewAdActionData($ModelAd=null,$ModelCat=null,$ad_id=0)
	{
		$Data = new stdClass();
		$Data -> Ad = array();
		$Data -> ad_keep = 0;
		$Data -> path_way = '';
		
		try
		{
			$Ad = $ModelAd -> getAdById($ad_id);
			
			CheckData::existsDataObject($Ad);
		}
		catch (Exception_CheckData $e)
		{
			throw new Exception_440();
		}
		//Подключаем галерею
		Factory::fancyBox('a.ad_foto');
		
		$Data -> Ad = $Ad;
		$day = $Ad -> ad_keep - time();
		if($day > 0)
		{
			$day = (int) ($day / Str::DATE_DAY);
		}
		else
		{
			$day = 0;
		}
		$Data -> ad_keep = $day; 

		//Формируем path way
		$path_way = Category::getPathWayStr($ModelCat -> prepCategory("getCategory"),$Ad -> cat_id);
		if($path_way)
		{
			$Data -> path_way = substr($path_way,0,-9);
		}
		return $Data;
	}
	
	/*****************************************************************************************************************/
	/********************************************** УДАЛЕНИЕ ФОТОГРАФИИ ***********************************************/	
	/*****************************************************************************************************************/
	
	/**
	 * Удаляет фотографию объявления (см. deletefotoAction)
	 *
	 * @param object $ModelAd модель объявления
	 * @param int $ad_id id объявления
	 */
	public function deleteFotoAdAction($ModelAd = NULL, $ad_id=0)
	{
		//Получаем данные для формирования списка рубрик в виде таблицы
		$this -> deleteFileFoto($ModelAd,$ad_id);
		
		//Удаляем фотографию с БД
		$ModelAd -> updateAdFotoById($ad_id, NULL);
	}
	
	/**
	 * Удаляем доп. фото объявления
	 *
	 * @param int $im_id ID доп. фото
	 * @param int $ad_id ID объявления
	 */
	public function deleteAddFoto($im_id = 0, $ad_id = 0)
	{
		//Получаем данные с БД
		$Im = Models_Images::instance() -> getImagesById($im_id);
		
		if($Im -> im_img)
		{
			Modules_Board_Models_Ad::deleteImg($Im -> im_img);
		}
		//Удаляем данные с БД
		Models_Images::instance() -> deleteByIdObjId($im_id, $ad_id);
	}
	
	/**
	 * Удаляем все дополнительные изображения объявления
	 *
	 * @param int $ad_id ID объявления
	 */
	public function deleteAddFotos($ad_id = 0)
	{
		//Получаем доп. изображения
		$ImagesAr = Models_Images::instance() -> getListImagesByObjId($ad_id, Modules_Board_Controllers_Index::GROUP_IMG);

		//Удаляем файлы доп. изображений
		if(sizeof($ImagesAr) > 0)
		{
			foreach($ImagesAr as $Img)
			{
				Modules_Board_Models_Ad::deleteImg($Img -> im_img);
			}
			//Удаляем доп. изображения
			Models_Images::instance() -> deleteByObjId($ad_id, Modules_Board_Controllers_Index::GROUP_IMG);
		}
	}
	
	/**
	 * Удаляем объявление
	 *
	 * @param object $ModelAd модель объявления
	 * @param object $CompRating компонент рейтинг
	 * @param int $ad_id id объявления
	 */
	public function deleteAdAction($ModelAd=null,$CompRating=null,$ad_id=0)
	{
		//Получаем данные для формирования списка рубрик в виде таблицы
		$this -> deleteFileFoto($ModelAd,$ad_id);
		
		//Удаляем данные с БД
		$ModelAd -> deleteAdById($ad_id);
		//Удаляем рейтинг объявлений
		$CompRating -> getModel() -> deleteRatingById($ad_id);
	}
	
	/**
	 * Удаляем фотографию объявления
	 *
	 */
	public function deleteFileFoto($ModelAd=null,$ad_id=0)
	{
		//Получаем фото объявления
		$Ad = $ModelAd -> getAdById($ad_id);
		//Удаляем фото
		Modules_Board_Models_Ad::deleteImg($Ad -> ad_foto);	
	}
}