<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Библиотека "Migration" модуля "Board"
 */

class Modules_Board_Libs_Migration
{
	/**
	 * Формирует данные для экспорта в формате xml
	 *
	 * @param array $AdsAr массив объектов объявлений
	 */
	public function exportXML(array $AdsAr = array())
	{
		$c  = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>\n";
		$c .= "<data>\n";
		
		foreach ($AdsAr as $Ad)
		{
			$c .= "\t<ad>\n";
			foreach ($Ad as $key => $val)
			{
				$c .= "\t\t<".$key.">";
				$c .= "<![CDATA[".$val."]]>";
				$c .= "</".$key.">\n";
			}
			$c .= "\t</ad>\n";
		}
		$c .= "</data>\n";
		
		return $c;
	}
	
	/**
	 * Формирует данные для экспорта в формате csv
	 *
	 * @param array $AdsAr массив объектов объявлений
	 */
	public function exportCSV(array $AdsAr = array())
	{
		$c = '';
		
		foreach ($AdsAr as $Ad)
		{
			$l = '';
			foreach ($Ad as $val)
			{
				$l .= "\"".strtr($val,array('"' => '""'))."\";";
			}
			$c .= substr($l,0,-1)."\n";
		}
		
		return $c;
	}
	
	/**
	 * Возвращает ассоциативный массив с XML файла для импорта данных
	 *
	 * @param string $path_to_file путь к файлу
	 * @return array
	 */
	public function importXML($path_to_file = NULL)
	{
		$data_ar = array();
		$i = 0;
		
		$XML = XML::getObj(File::read($path_to_file),false) -> ad;
		foreach ($XML as $ad)
		{
			foreach ($ad as $key => $val)
			{
				$data_ar[$i][(string)$key] = (string)$val;
			}
			$i++;
		}
		
		return $data_ar;
	}

	/**
	 * Возвращает ассоциативный массив с CSV файла для импорта данных
	 *
	 * @param string $path_to_file путь к файлу
	 * @return array
	 */
	public function importCSV($path_to_file = NULL)
	{
		//!!!Последовательность полей должна следовать последовательности полей в БД
		
		$CSV = new Reader_Csv();
		$CSV -> settings(array(
			'delimiter' => ';',
		));
		$CSV -> load($path_to_file);
		$CSV -> setHeaders(array(
			'ad_id',
			'us_id',
			'ad_name',
			'ad_email',
			'ad_phone',
			'ad_site',
			'ad_title',
			'ad_text',
			'ad_region',
			'cat_id',
			'ad_foto',
			'ad_is_lock',
			'ad_keep',
			'ad_date',
			'ad_count_shows',
			'ad_vip_date',
			'ad_style',
			'ad_style_date',
			'ad_topin_date',
			'ad_code',
		));
		
		return $CSV -> connect();
	}
	
	/**
	 * Возвращает ассоциативный массив с XLS файла для импорта данных
	 *
	 * @param string $path_to_file путь к файлу
	 * @return array
	 */
	public function importXLS($path_to_file = NULL)
	{
		//!!!Последовательность полей должна следовать последовательности полей в БД
		
		//Установка данных
		$key2row_ar = array(
			1 => 'ad_id',
			2 => 'us_id',
			3 => 'ad_name',
			4 => 'ad_email',
			5 => 'ad_phone',
			6 => 'ad_site',
			7 => 'ad_title',
			8 => 'ad_text',
			9 => 'ad_region',
			10 => 'cat_id',
			11 => 'ad_foto',
			12 => 'ad_is_lock',
			13 => 'ad_keep',
			14 => 'ad_date',
			15 => 'ad_count_shows',
			16 => 'ad_vip_date',
			17 => 'ad_style',
			18 => 'ad_style_date',
			19 => 'ad_topin_date',
			20 => 'ad_code',
		);		
		$data_ar = array();
		
		$Excel = new Reader_Excel();
		$Excel -> setOutputEncoding('utf-8');
		$Excel -> read($path_to_file);
		
		if(isset($Excel -> sheets[0]['numRows']) && isset($Excel -> sheets[0]['numCols']))
		{
			for ($i = 1; $i <= $Excel -> sheets[0]['numRows']; $i++)
			{
				for ($j = 1; $j <= $Excel -> sheets[0]['numCols']; $j++)
				{
					$data_ar[$i][$key2row_ar[$j]] = isset($Excel -> sheets[0]['cells'][$i][$j]) ? trim($Excel -> sheets[0]['cells'][$i][$j]) : ''; 
				}
			}
		}
		
		return $data_ar;
	}
}