<?php defined("MOMENT_BOARD") or die("Access denied");
/**
 * @package MomentBoard v2.0
 * @copyright (c) guardeon.biz
 * @link http://guardeon.biz/
 * @author Pavel <support@guardeon.biz>
 * @desc Модель "Category" модуля "Доска объявлений"
 */

class Modules_Board_Models_Category extends Models_Category
{
	public function __construct()
	{
		parent::__construct("board");
	}

	/**
	 * Возвращает объект
	 *
	 * @return object
	 */
	public static function instance()
	{
		static $Instance;
		
		if(!is_object($Instance))
		{
			$Instance = new self;
		}
		return $Instance;
	}
	
	/**
	 * Возвращает данные категории
	 *
	 * @param int $cat_id
	 * @return array
	 */
	public function getCategoryById($cat_id=0)
	{
		return parent::getDataById($cat_id);
	}
	
	/**
	 * Возвращает список категорий
	 *
	 * @return array
	 */
	public function getCategory()
	{
		return parent::getListData();
	}
	
	/**
	 * Возвращает количество объявлений категорий
	 *
	 * @return array
	 */
	public function getCountAdInCategory()
	{
		$sql = "SELECT `c`.`cat_id`, `c`.`cat_parent_id`, COUNT(`a`.`ad_id`) AS `count_ad` 
			FROM 
		`#__sys_category` AS `c`  
			LEFT JOIN 
		`#__mod_board_ad` AS `a` 
			ON(`c`.`cat_id`=`a`.`cat_id` AND `a`.`ad_is_lock`='0') 
			WHERE 
		`c`.`cat_group`='".$this -> group."' 
			GROUP BY `c`.`cat_id`";
		
		$result = $this -> DB -> setQuery($sql,"Не удалось получить количество объявлений рубрик");
		
		$cat_ar = array();
		while($Cat = $this -> DB -> getObject($result))
		{
			$cat_ar[$Cat -> cat_parent_id][$Cat -> cat_id] = $Cat -> count_ad;
		}
		
		return $cat_ar;
	}
	
	/**
	 * Возвращает общее количество объявлений в категориях $cat_ar
	 *
	 * @param array $cat_ar
	 * @return int
	 */
	public function getCountAdInCategoryByCatAr($cat_ar=array())
	{
		$sql = "SELECT `a`.`ad_id`  
			FROM 
		`#__sys_category` AS `c`  
			LEFT JOIN 
		`#__mod_board_ad` AS `a` 
			ON(`c`.`cat_id`=`a`.`cat_id` AND `a`.`ad_is_lock`='0') 
			WHERE 
		`c`.`cat_group`='".$this -> group."'
			AND 
		`a`.`cat_id` IN(".join(",",array_map("intval",$cat_ar)).")";
		
		return $this -> DB -> setQuery($sql,"Не удалось получить количество объявлений рубрик","getCount");
	}
	
	/**
	 * Возвращает рубрики по $parent_id
	 *
	 * @param array $parent_ar
	 * @return array
	 */
	public function getCategoryByParentAr(array $parent_ar = array())
	{
		if(sizeof($parent_ar) == 0)
		{
			return array();
		}
		
		$sql = "SELECT `cat_id`, `cat_parent_id`, `cat_title` 
			FROM 
		`#__sys_category` 
			WHERE 
		`cat_parent_id` IN (".join(',',$parent_ar).")
			AND 
		`cat_group`='".$this -> group."'
			ORDER BY 
		`cat_order`, `cat_title` ASC";
		
		$result = $this -> DB -> setQuery($sql,"Не удалось получить данные рубрик");
		
		$cat_ar = array();
		while($Cat = $this -> DB -> getObject($result))
		{
			$cat_ar[$Cat -> cat_parent_id][$Cat -> cat_id] = $Cat -> cat_title;
		}
		
		return $cat_ar;
	}
	
	/**
	 * Определяет количество рубрик у массива родителей $parent_ar
	 *
	 * @param array $parent_ar
	 * @return array
	 */
	public function getCountChildCategoryByPCatAr($parent_ar=array())
	{
		$cat_ar = array();
		if(sizeof($parent_ar) > 0)
		{
			$sql = "SELECT `cat_parent_id`, COUNT(`cat_id`) AS `count_cat` 
				FROM 
			`#__sys_category` 
				WHERE 
			`cat_parent_id` IN(".join(",",array_map("intval",$parent_ar)).")
				AND 
			`cat_group`='".$this -> group."'
				GROUP BY `cat_parent_id`";
			
			$result = $this -> DB -> setQuery($sql,"Не удалось определить количество подчиненных рубрик");
			
			$cat_ar = array();
			while($Cat = $this -> DB -> getObject($result))
			{
				$cat_ar[$Cat -> cat_parent_id] = $Cat -> count_cat;
			}
		}
		return $cat_ar;
	}
	
	/**
	 * Обновляет данные катнгории
	 *
	 * @param int $cat_id
	 * @param int $parent_id
	 * @param string $title
	 * @param int $order
	 */
	public function updateCategoryById($cat_id = 0, $parent_id = 0, $title = NULL, $cat_meta_keywords = NULL, $cat_meta_description = NULL, $order = 0)
	{
		parent::updateDataCategory($cat_id, $parent_id, strip_tags($title), strip_tags($cat_meta_keywords), strip_tags($cat_meta_description), $order);
	}
	
	/**
	 * Обновляем сортировку рубрики
	 *
	 * @param int $cat_id id рубрики
	 * @param int $order порядковый номер рубрики
	 */
	public function updateCategoryOrdersById($cat_id = 0, $order = 0)
	{
		parent::updateOrder($cat_id,$order);
	}
	
	/**
	 * Удаляет категорию по ее id
	 *
	 * @param int $cat_id
	 */
	public function deleteCategoryById($cat_id=0)
	{
		parent::deleteByIdCategory($cat_id);
	}
	
	/**
	 * Проверяет существование категории
	 *
	 * @param int $cat_id
	 */
	public function isExistsCategory($cat_id=0)
	{
		return parent::isExistsCategory($cat_id);
	}
}